// The demonstration game for The Quill Adventure Writer by Zeljko Juric.
// Originally written by R.G.Hallas for ZX Spectrum with Gilsoft's The Quill.
// Significantly improved and ported to TI by Zeljko Juric.

// This game is a coding example, which illustrates some more advanced coding
// tricks, like implementation of quite inteligent parser which works well 
// with similar objects with and without object adjectives, working with
// more instances of similar objects (three keys, two cubboards) etc.

$$TITLE("Escape")

// +-----------------+
// | Aliases Section |
// +-----------------+

// Locations aliases

DEFINE(INTRO,0)
DEFINE(BEDROOM,1)
DEFINE(HALL,2)
DEFINE(TOILET,3)
DEFINE(LIVING_ROOM,4)
DEFINE(DINING_ROOM,5)
DEFINE(KITCHEN,6)
DEFINE(HALL_2,7)
DEFINE(STUDY,8)
DEFINE(LANDING,9)
DEFINE(SPARE_BEDROOM,10)
DEFINE(OUTSIDE,11)

// Objects aliases

DEFINE(BED,0)
DEFINE(IRON_KEY,1)
DEFINE(CL_CUPBOARD,2)
DEFINE(OP_CUPBOARD,3)
DEFINE(CL_SAFE,4)
DEFINE(OP_SAFE,5)
DEFINE(LARGE_KEY,6)
DEFINE(TOILET_OBJ,7)
DEFINE(TV,8)
DEFINE(COMPUTER,9)
DEFINE(FRUIT,10)
DEFINE(CL_FRIDGE,11)
DEFINE(OP_FRIDGE,12)
DEFINE(MILLET,13)
DEFINE(CHEESE,14)
DEFINE(DESK,15)
DEFINE(SMALL_KEY,16)
DEFINE(TWO_BEDS,17)
DEFINE(CL_CUPB_2,18)
DEFINE(OP_CUPB_2,19)
DEFINE(CLOTHES,20)
DEFINE(BUDGIE,21)

// Flags aliases

DEFINE(TOILET_OPENED,11)               // Notzero if the toilet is open
DEFINE(TOILET_DONE,12)                 // Notzero if "toilet job" is done
DEFINE(DOOR_OPENED,13)                 // Notzero if the main door is open
DEFINE(LAST_VERB,14)                   // Saves temporary the last used verb
DEFINE(LAST_NOUN,15)                   // Saves temporary the last used noun
DEFINE(WHICH_KEY,16)                   // Adjective for the referenced key
DEFINE(WHERE_IS_KEY,17)                // The location of the referenced key

// Other aliases

DEFINE(AMBIGUOUS,200)                  // "Ambiguity" indicator

$$VOCABULARY(4)

// +--------------------+
// | Vocabulary Section |
// +--------------------+

WORD(1,N)
WORD(1,NORT)
WORD(2,S)
WORD(2,SOUT)
WORD(3,E)
WORD(3,EAST)
WORD(4,W)
WORD(4,WEST)
WORD(5,NE)
WORD(6,NW)
WORD(7,SE)
WORD(8,SW)
WORD(9,U)
WORD(9,UP)
WORD(9,CLIMB)
WORD(9,ASCEND)
WORD(10,D)
WORD(10,DOWN)
WORD(10,DESCEND)
WORD(16,BEDROOM)
WORD(17,TOILET)
WORD(18,HALL)
WORD(19,LIVING)
WORD(20,DINING)
WORD(21,KITCHEN)
WORD(22,STUDY)
WORD(23,LANDING)
WORD(24,SPARE)
WORD(25,KEY)
WORD(26,CUPBOARD)
WORD(27,SAFE)
WORD(28,TV)
WORD(28,TELEVISION)
WORD(29,COMPUTER)
WORD(30,FRUIT)
WORD(31,MILLET)
WORD(32,CHEESE)
WORD(33,FRIDGE)
WORD(34,DESK)
WORD(35,BED)
WORD(36,CLOTHES)
WORD(37,ON)
WORD(38,OFF)
WORD(39,BUDGIE)
WORD(40,OPEN)
WORD(40,UNLOCK)
WORD(41,CLOSE)
WORD(41,SHUT)
WORD(41,LOCK)
WORD(42,LIE)
WORD(43,EAT)
WORD(44,KILL)
WORD(44,HIT)
WORD(44,KICK)
WORD(45,IRON)
WORD(46,SMALL)
WORD(47,LARGE)
WORD(48,SIT)
WORD(49,DOOR)
WORD(50,OUT)
WORD(51,IN)
WORD(52,SCORE)
WORD(53,SEARCH)
WORD(53,EXAMINE)
WORD(53,LOOK)
WORD(100,GET)
WORD(100,TAKE)
WORD(101,DROP)
WORD(102,REMOVE)
WORD(103,WEAR)
WORD(104,I)
WORD(104,INVENTORY)
WORD(105,R)
WORD(105,REDESCRIBE)
WORD(106,QUIT)
WORD(106,STOP)
WORD(107,SAVE)
WORD(108,LOAD)
WORD(108,RESTORE)
WORD(150,WITH)                         // Preposition...

$$LOCATIONS

// +-------------------+
// | Locations Section |
// +-------------------+

LOC($INTRO,"Welcome to 'Escape!'.\n\n"
    "In this adventure, you must simply get out of your house. However, "
    "you've forgotten where you put the key to the front door...\n\n"
    "Hint: Be careful of the dreaded Budgie!\n\n"
    "Enter 'SCORE' to find out your score.\n\n"
    "Originally written by R. G. Hallas.\n"
    "Adapted and improved by Zeljko Juric.")
LOC($BEDROOM,"You are in the bedroom.\n"
    "The hall is to the west.")
LOC($HALL,"You are in the hall.\n"
    "The toilet is to the north, the hall continues to the south, the "
    "bedroom is to the east, and the living room is to the west.")
LOC($TOILET,"You are in the toilet.\n"
    "The hall is to the south.")
LOC($LIVING_ROOM,"You are in the living room.\n"
    "The hall is to the east, and the dining room is to the south.")
LOC($DINING_ROOM,"You are in the dining room.\n"
    "The living room is to the north, and the kitchen is to the east.")
LOC($KITCHEN,"You are in the kitchen.\n"
    "The dining room is to the west, and the hall is to the east.")
LOC($HALL_2,"You are in the hall.\n"
    "The hall continues to the north, the kitchen is to the west, the front "
    "door is to the south, and stairs lead up.")
LOC($STUDY,"You are in the study.\n"
    "The landing is to the east.")
LOC($LANDING,"You are on the landing.\n"
    "The study is to the west, and the spare bedroom is to the east. "
    "Stairs lead down.")
LOC($SPARE_BEDROOM,"You are in the spare bedroom.\n"
    "The landing is to the west.")
LOC($OUTSIDE,"YIPPEE!\n\n"
    "You are outside!!!")

$$MESSAGES

// +------------------+
// | Messages Section |
// +------------------+

MSG(0,"The computer is faulty, and explodes.\n")
MSG(1,"\nThe budgie flies at you to get at the millet, and scares the living "
    "daylight out of you!\n")
MSG(2,"You lie down and fall asleep.\n")
MSG(3,"The cheese was off.\n")
MSG(4,"You turn the television on. It's showing Crossroads... wildly "
    "exciting. You turn it off again in disgust.")
MSG(5,"Don't be so cruel.")
MSG(6,"\nSadly, you are arrested for wearing no clothes...\n")
MSG(7,"Ouch! A moth flies out of the cupboard and scares you...\n")
MSG(8,"You can't go out because the door is locked.")
MSG(9,"You can't go in because the door is locked.")
MSG(10,"The fruit was very juicy...")
MSG(11,"Whew! Just made it!")
MSG(12,"Oh dear, you didn't make it to the toilet quickly enough...\n")
MSG(13,"\nQuick! To the toilet! You haven't much time...")
MSG(14,"\nWell done! You have solved the adventure!")
MSG(15,"You need to pick it up first.")

$$SYSTEM_MESSAGES

// +-------------------------+
// | System Messages Section |
// +-------------------------+

MSG(1,"\nYou can also see:")
MSG(2,"\nI await your command.")
MSG(3,"\nI'm ready for your instructions.")
MSG(4,"\nTell me what to do.")
MSG(5,"\nGive me your command.")
MSG(6,"I don't understand any words in that sentence.")
MSG(7,"You can't go in that direction.")
MSG(8,"You can't do that.")
MSG(9,"You have:")
MSG(10," (worn)")
MSG(11,"Nothing at all.")
MSG(12,"Do you really want to quit now?")
MSG(13,"\nEND OF GAME\n\nDo you want to try again?")
MSG(14,"\nBye. Have a nice day.")
MSG(15,"Okay.")
MSG(16,"\nPress any key to continue.")
MSG(17,"You have taken ")
MSG(18," turn")
MSG(19,"s")
MSG(20,".")
MSG(21,"You have scored ")
MSG(22,"%")
MSG(23,"You're not wearing it.")
MSG(24,"You can't. Your hands are full.")
MSG(25,"You already have it.")
MSG(26,"It's not here.")
MSG(27,"You can't carry any more.")
MSG(28,"You don't have it.")
MSG(29,"You're already wearing it.")
MSG(30,"Y")
MSG(31,"N")

// Extra prompts...

MSG(32,"Which key?")
MSG(33,"With what?")

$$OBJECTS(2)                           // The player can carry 2 objects

// +-----------------+
// | Objects Section |
// +-----------------+

// Note that there are even three keys in this game ("iron key", "small key"
// and "large key"). They may be refered using adjectives IRON, SMALL and 
// LARGE respectively, but smart coding allows even refering to all of them
// using a generic word "key" (for example, DROP KEY), except in ambiguous 
// situations. In such cases, a prompt "Which key?" will appear. Look further
// to see how this is implemented exactly.

OBJ($BED,"A bed.",_,$BEDROOM)
OBJ($IRON_KEY,"An iron key.",IRON,$NOWHERE)
OBJ($CL_CUPBOARD,"A closed cupboard.",_,$HALL_2)
OBJ($OP_CUPBOARD,"An open cupboard.",_,$NOWHERE)
OBJ($CL_SAFE,"A closed safe.",_,$NOWHERE)
OBJ($OP_SAFE,"An open safe.",_,$NOWHERE)
OBJ($LARGE_KEY,"A large key.",LARGE,$NOWHERE)
OBJ($TOILET_OBJ,"A toilet.",_,$TOILET)
OBJ($TV,"A television.",_,$LIVING_ROOM)
OBJ($COMPUTER,"A computer.",_,$LIVING_ROOM)
OBJ($FRUIT,"Some fruit.",FRUIT,$DINING_ROOM)
OBJ($CL_FRIDGE,"A closed fridge.",_,$KITCHEN)
OBJ($OP_FRIDGE,"An open fridge.",_,$NOWHERE)
OBJ($MILLET,"A millet.",MILLET,$KITCHEN)
OBJ($CHEESE,"Some cheese.",CHEESE,$NOWHERE)
OBJ($DESK,"A desk.",_,$STUDY)
OBJ($SMALL_KEY,"A small key.",SMALL,$NOWHERE)
OBJ($TWO_BEDS,"Two beds.",_,$SPARE_BEDROOM)
OBJ($CL_CUPB_2,"A closed cupboard.",_,$SPARE_BEDROOM)
OBJ($OP_CUPB_2,"An open cupboard.",_,$NOWHERE)
OBJ($CLOTHES,"Some clothes.",CLOTHES,$NOWHERE)
OBJ($BUDGIE,"A Budgie.",_,$LIVING_ROOM)

$$CONNECTIONS

// +---------------------+
// | Connections Section |
// +---------------------+

FROM($BEDROOM)
    CONN(W,$HALL)
    CONN(HALL,$HALL)
    
FROM($HALL)
    CONN(N,$TOILET)
    CONN(E,$BEDROOM)
    CONN(S,$HALL_2)
    CONN(W,$LIVING_ROOM)
    CONN(TOILET,$TOILET)
    CONN(BEDROOM,$BEDROOM)
    CONN(HALL,$HALL_2)    
    CONN(LIVING,$LIVING_ROOM)
    
FROM($TOILET)
    CONN(S,$HALL)
    CONN(OUT,$HALL)
    CONN(HALL,$HALL)
    
FROM($LIVING_ROOM)
    CONN(E,$HALL)
    CONN(S,$DINING_ROOM)
    CONN(HALL,$HALL)    
    CONN(DINING,$DINING_ROOM)    

FROM($DINING_ROOM)
    CONN(N,$LIVING_ROOM)
    CONN(E,$KITCHEN)
    CONN(LIVING,$LIVING_ROOM)
    CONN(KITCHEN,$KITCHEN)
    
FROM($KITCHEN)
    CONN(W,$DINING_ROOM)
    CONN(E,$HALL_2)
    CONN(DINING,$DINING_ROOM)
    CONN(HALL,$HALL_2)
    
FROM($HALL_2)
    CONN(N,$HALL)
    CONN(W,$KITCHEN)
    CONN(U,$LANDING)
    CONN(HALL,$HALL)
    CONN(KITCHEN,$KITCHEN)
    CONN(LANDING,$LANDING)
    
FROM($STUDY)
    CONN(E,$LANDING)
    CONN(LANDING,$LANDING)
    
FROM($LANDING)
    CONN(W,$STUDY)
    CONN(E,$SPARE_BEDROOM)
    CONN(D,$HALL_2)
    CONN(STUDY,$STUDY)
    CONN(SPARE,$SPARE_BEDROOM)
    CONN(BEDROOM,$SPARE_BEDROOM)
    CONN(HALL,$HALL_2)
    
FROM($SPARE_BEDROOM)
    CONN(W,$LANDING)
    CONN(LANDING,$LANDING)

$$EVENTS

// +----------------+
// | Events Section |
// +----------------+

EVENT
    ISDESC                             // Description in progress?
    CLS                                // Clear screen
    SHOWLOC                            // Display the location
    NEWLINE
    LISTOBJ                            // List objects

EVENT
    AT($INTRO)                         // Intro?
    ANYKEY                             // Wait for a keypress
    GOTO($BEDROOM)                     // The game starts in the bedroom
    DESC

EVENT
    NOTZERO($CNT1)                     // Fruit-eaten counter is nonzero?
    ZERO($TOILET_DONE)                 // The "job in toilet" is not done?
    MESSAGE(13)                        // Quick, to the toilet...
    
EVENT
    EQ($CNT1,1)                        // Time expired?
    ZERO($TOILET_DONE)                 // The "job in toilet" is not done?
    MESSAGE(12)                        // Not quick enough...
    SCORE                              // Bad luck!
    TURNS
    END
    
EVENT
    AT($LIVING_ROOM)                   // Living room?
    CARRIED($MILLET)                   // Millet carried?
    MESSAGE(1)                         // The Budgie flies at you...
    SCORE                              // Bad luck!
    TURNS
    END

EVENT
    AT($OUTSIDE)                       // Outside?
    NOTWORN($CLOTHES)                  // No clothes worn?
    MESSAGE(6)                         // You are arrested...
    SCORE                              // Bad luck!
    TURNS
    END

EVENT
    AT($OUTSIDE)                       // Outside?
    MESSAGE(14)                        // Well done...
    SCORE
    TURNS
    END
    
$$ACTIONS

// +-----------------+
// | Actions Section |
// +-----------------+

// The first part of the action section is somewhat tricky, to make the parser
// a bit more inteligent than usual. For example, pick up both the iron key
// and the small key, then try to open the toilet door. The correct sentence
// is OPEN DOOR WITH IRON KEY, but the following dialog is possible:
//
// Tell me what to do.
// OPEN DOOR
//
// With what?
// WITH KEY
//
// Which key?
// IRON
//
// Okay.
//
// Alternatively, the following dialog is also possible:
//
// Tell me what to do.
// OPEN DOOR WITH KEY
//
// Which key?
// IRON KEY
//
// Okay.
//
// Or, the following one:
//
// Tell me what to do.
// OPEN DOOR
//
// With what?
// WITH IRON KEY
//
// Okay.
//
// Check following entries carefully if you want to learn how to implement
// such "clever" behaviour, and trace what exactly happens when you play a
// dialog shown above. Note, however, that this is an advanced coding method,
// which is not adequate for absolute beginners.

// The sentence can begin with "WITH" only if the prompt was "With what?"...

ACTION(WITH,_)
    NOTEQ($PROMPT,33)                  // Prompt is not "With what?"?
    PROMPT(0)                          // Restore the standard prompt
    NOTDONE                            // Nonsense...

// Valid responses to "Which key?" prompt...

ACTION(IRON,_)
    EQ($PROMPT,32)                     // "Which key?" prompt?
    COPYFF($LAST_VERB,$VERB)           // Restore the last used verb and set
    SETNOUN(IRON)                      //   the adjective to be IRON (KEY)
    PROMPT(0)                          // Restore the standard prompt
    CANCEL                             // Continue scanning with the old verb

ACTION(SMALL,_)
    EQ($PROMPT,32)                     // "Which key?" prompt?
    COPYFF($LAST_VERB,$VERB)           // Restore the last used verb and set
    SETNOUN(SMALL)                     //   the adjective to be SMALL (KEY)
    PROMPT(0)                          // Restore the standard prompt
    CANCEL                             // Continue scanning with the old verb

ACTION(LARGE,_)
    EQ($PROMPT,32)                     // "Which key?" prompt?
    COPYFF($LAST_VERB,$VERB)           // Restore the last used verb and set
    SETNOUN(LARGE)                     //   the adjective to be LARGE (KEY)
    PROMPT(0)                          // Restore the standard prompt
    CANCEL                             // Continue scanning with the old verb

// Any other response to "Which key?" is meaningless in this game...
    
ACTION(_,_)
    EQ($PROMPT,32)                     // "Which key?" prompt?
    PROMPT(0)                          // Switch back to the standard prompt
    SYSMESS(8)                         // You can't (note that usage of
    NEWLINE                            //   NOTDONE would produce different
    DONE                               //   response to movement words)...

// Save the verb to be eventually restored in the next turn if necessary...

ACTION(_,_)
    COPYFF($VERB,$LAST_VERB)           // Save the verb
    CANCEL                             // Do not count this as an 'action'

// To make the game harder, the safe and the doors can not be opened by typing
// simple phrases like OPEN SAFE or OPEN DOOR. Phrases like OPEN SAFE WITH KEY 
// or OPEN DOOR WITH IRON KEY are necessary. Typing simply OPEN DOOR should 
// produce "With what?" prompt. Typing OPEN DOOR WITH KEY should produce
// "Which key?" prompt if the player carries more different keys. However, the
// cupboards and the fridge may be opened unconditionally by typing simply
// OPEN CUPBOARD or OPEN FRIDGE. Here is a set of auxilary entries which
// extract necessary information about eventual presence of WITH _noun2_
// construction after OPEN _noun1_, which are eventually needed later. Note 
// that this is an example of quite advanced coding...

ACTION(_,_)
    SET($WHICH_KEY)                    // Assume "No key so far" ($NULL)
    CANCEL                             // Signal "nothing important"...

ACTION(OPEN,_)
    EXTWORD(WITH)                      // Preposition WITH present?
    COPYFF($NOUN,$LAST_NOUN)           // Save the original noun
    GETWORD($NOUN)                     // Set noun to be the word after WITH    
    SETVERB(WITH)                      // Continue through ACTION(WITH,...)

// Valid responses to "With what?" prompt...

ACTION(WITH,SMALL)
    LET($WHICH_KEY,$SMALL_KEY)         // Adjective SMALL -> "small key"
    
ACTION(WITH,LARGE)
    LET($WHICH_KEY,$LARGE_KEY)         // Adjective LARGE -> "large key"

ACTION(WITH,IRON)
    LET($WHICH_KEY,$IRON_KEY)          // Adjective IRON -> "iron key"

ACTION(WITH,KEY)                       // KEY without an adjective may be
    LET($WHICH_KEY,$AMBIGUOUS)         //   ambiguous sometimes...
    CARRIED($IRON_KEY)
    NOTCARR($SMALL_KEY)                // If the iron key is the only key
    NOTCARR($LARGE_KEY)                //   which is carried, KEY means
    LET($WHICH_KEY,$IRON_KEY)          //   "iron key"
  ELSE
    NOTCARR($IRON_KEY)                 // If the small key is the only key
    CARRIED($SMALL_KEY)                //   which is carried, KEY means
    NOTCARR($LARGE_KEY)                //   "small key"
    LET($WHICH_KEY,$SMALL_KEY)
  ELSE
    NOTCARR($IRON_KEY)                 // If the large key is the only key
    NOTCARR($SMALL_KEY)                //   which is (eventually) carried,
    LET($WHICH_KEY,$LARGE_KEY)         //   KEY means "large key"

// Note that if the player has no any keys, the key type is set to be equal to
// "large key", but the next entry will fail in this case (you don't have it)

ACTION(WITH,_)
    PROMPT(0)                          // Restore the standard prompt
    ISNULL($WHICH_KEY)                 // WITH together with anything except
    SYSMESS(8)                         //   a key is meaningless in this
    NEWLINE                            //   game...
    DONE
  ELSE
    WHEREO($WHICH_KEY,$WHERE_IS_KEY)   // Where is the referenced key?
    NOTEQ($WHERE_IS_KEY,$CARRIED)      // Not carried?
    NOTEQ($WHICH_KEY,$AMBIGUOUS)       // Not an ambigous situation?
    SYSMESS(28)                        // You don't have it...
    NEWLINE
    DONE
  ELSE    
    COPYFF($LAST_NOUN,$NOUN)           // Restore the original noun
    SETVERB(OPEN)                      // Continue as if the verb is OPEN
    CANCEL                             //   (but now with more info extracted)

// Any other responses to "With what?" are meaningless in this game...
    
ACTION(_,_)
    EQ($PROMPT,33)                     // "With what?" prompt?
    PROMPT(0)                          // Switch back to the standard prompt
    SYSMESS(8)                         // You can't (note that usage of
    NEWLINE                            //   NOTDONE would produce different
    DONE                               //   response to movement words)...

// Save the noun to be eventually restored in the next turn if necessary...

ACTION(_,_)
    COPYFF($NOUN,$LAST_NOUN)
    CANCEL

// The tricky part of the Actions Section is finished. Now follows a set of
// more or less "standard" action entries...

ACTION(TOILET,_)                       // This means ENTER TOILET, GO TOILET,
    AT($HALL)                          //   etc. (note that ENTER and GO are
    SETVERB(N)                         //   not in the vocabulary)

ACTION(IN,_)
    AT($HALL)                          // IN has the same sense...
    SETVERB(N)

ACTION(N,_)
    AT($HALL)                          // Hall?
    ZERO($TOILET_OPENED)               // Toilet not open?
    MESSAGE(9)                         // Door is locked...
    DONE                               //   (otherwise scan further)

ACTION(OUT,_)
    AT($HALL_2)                        // Second hall?
    SETVERB(S)                         // Going OUT here means goind south...
    
ACTION(S,_)
    AT($HALL_2)                        // Second hall?
    ZERO($DOOR_OPENED)                 // Door not open?
    MESSAGE(8)                         // Sorry...
    DONE
  ELSE
    AT($HALL_2)                        // Otherwise: Second hall (but door is
    GOTO($OUTSIDE)                     //   open)?
    PLUS($SCORE,25)                    // Go outside, and give the final
    DESC                               //   set of points...

ACTION(_,_)
    TRYMOVE                            // Try to perform standard movements
    DESC                               //   through the Connections Section

ACTION(ON,TV)
    AT($LIVING_ROOM)                   // Living room?
    MESSAGE(4)                         // Showing crossroads...
    DONE

ACTION(TV,ON)
    AT($LIVING_ROOM)                   // The same...
    MESSAGE(4)
    DONE
    
ACTION(COMPUTER,ON)
    AT($LIVING_ROOM)                   // Living room?
    MESSAGE(0)                         // Faulty...
    SCORE                              // Bad luck!
    TURNS
    END
    
ACTION(ON,COMPUTER)
    AT($LIVING_ROOM)                   // The same...
    MESSAGE(0)
    SCORE
    TURNS
    END
    
ACTION(LIE,_)
    MESSAGE(2)                         // You fall asleep...
    SCORE                              // Bad luck!
    TURNS
    END
    
ACTION(EAT,FRUIT)
    CARRIED($FRUIT)                    // Fruit carried?
    DESTROY($FRUIT)                    // Goodbye fruit...    
    MESSAGE(10)                        // Too juicy...
    LET($CNT1,8)                       // Set the counter...
    DONE
  ELSE
    PRESENT($FRUIT)                    // Otherwise: here (but not carried)?
    MESSAGE(15)                        // Pick up it first...
    
ACTION(EAT,CHEESE)
    CARRIED($CHEESE)                   // Cheese carried?
    MESSAGE(3)                         // Cheese was off...
    SCORE                              // Bad luck!
    TURNS
    END
  ELSE
    PRESENT($FRUIT)                    // Otherwise: here (but not carried)?
    MESSAGE(15)                        // Pick up it first...
    
ACTION(KILL,BUDGIE)
    MESSAGE(5)                         // Don't be cruel...
    DONE
    
ACTION(SIT,_)
    AT($TOILET)                        // At toilet?
    NOTZERO($CNT1)                     // Urgency?
    SET($TOILET_DONE)                  // Signal "done"...
    PLUS($SCORE,25)                    // Give points for this nice job...
    MESSAGE(11)                        // Aaah...
    DONE
  ELSE
    OK                                 // Otherwise, nothing special

ACTION(LOOK,BED)
    PRESENT($BED)                      // Bed is here?
    NOTCREATED($IRON_KEY)              // Iron key not created yet?
    CREATE($IRON_KEY)                  // Create it (and scan further)...

ACTION(LOOK,DESK)
    PRESENT($DESK)                     // Desk is here?
    NOTCREATED($SMALL_KEY)             // Small key not created yet?
    CREATE($SMALL_KEY)                 // Create it (and scan further)...

ACTION(LOOK,_)
    DESC                               // Redescribe location unconditionally
    
ACTION(SCORE,_)
    SCORE
    TURNS

ACTION(OPEN,CUPBOARD)
    PRESENT($CL_CUPBOARD)              // Closed cupboard (first one) is here?
    SWAP($CL_CUPBOARD,$OP_CUPBOARD)    // Make it open
    CREATE($CL_SAFE)                   // Make the safe visible
    DESC                               // Redescribe
  ELSE
    PRESENT($CL_CUPB_2)                // Closed cupboard (another one) here?
    ZERO($TOILET_DONE)                 // Important jobs still not done?
    MESSAGE(7)                         // A moth flies out...
    SCORE                              // Bad luck!
    TURNS
    END
  ELSE
    PRESENT($CL_CUPB_2)                // Otherwise: Closed cupboard (2) here?
    NOTCREATED($CLOTHES)               // Clothes not created yet?
    CREATE($CLOTHES)                   // Well, create them
    PLUS($SCORE,25)                    // Give points (and continue further)
  CONTINUE
    PRESENT($CL_CUPB_2)                // Closed cupboard (2) here?
    SWAP($CL_CUPB_2,$OP_CUPB_2)        // Well, make it open
    DESC

ACTION(OPEN,FRIDGE)
    PRESENT($CL_FRIDGE)                // Closed fridge is here?
    NOTCREATED($CHEESE)                // Cheese not created yet?
    CREATE($CHEESE)                    // Create it (and continue further)
  CONTINUE
    PRESENT($CL_FRIDGE)                // Closed fridge is here?
    SWAP($CL_FRIDGE,$OP_FRIDGE)        // Make it open
    DESC                               // Redescribe

// Remember that if the player typed phrase like OPEN SAFE WITH SMALL KEY,
// flag $WHICH_KEY contains an information about this fact...

ACTION(OPEN,SAFE)
    PRESENT($CL_SAFE)                  // Closed safe is here?
    EQ($WHICH_KEY,$SMALL_KEY)          // WITH (SMALL) KEY phrase was given?
    NOTCREATED($LARGE_KEY)             // Large key not created it?
    CREATE($LARGE_KEY)                 // Create it
    PLUS($SCORE,25)                    // Give points (and continue further)
  CONTINUE
    PRESENT($CL_SAFE)                  // Closed safe is here?
    EQ($WHICH_KEY,$SMALL_KEY)          // WITH (SMALL) KEY phrase was given?
    SWAP($CL_SAFE,$OP_SAFE)            // Make the safe open
    DESC                               // Redescribe
  ELSE
    PRESENT($CL_SAFE)                  // Otherwise: If closed safe is here,
    EQ($WHICH_KEY,$AMBIGUOUS)          //   and phrase WITH KEY was given,
    PROMPT(32)                         //   but more than one key is carried,
  ELSE                                 //   then set prompt to "Which key?"
    PRESENT($CL_SAFE)                  // Otherwise: If closed safe is here,
    ISNULL($WHICH_KEY)                 //   phrase WITH _key_ was not given,
    PROMPT(33)                         //   then set prompt to "With what?"
    
ACTION(OPEN,TOILET)
    AT($HALL)                          // Hall?
    SETNOUN(DOOR)                      // Turn OPEN TOILET into OPEN DOOR

ACTION(OPEN,DOOR)
    AT($HALL)                          // Hall?
    ZERO($TOILET_OPENED)               // Toilet not opened yet?
    EQ($WHICH_KEY,$IRON_KEY)           // WITH (IRON) KEY phrase was given?
    SET($TOILET_OPENED)                // Well, open the toilet...
    OK
  ELSE
    AT($HALL)                          // Otherwise: If at hall, toilet is not
    ZERO($TOILET_OPENED)               //   opened, phrase WITH KEY was given,
    EQ($WHICH_KEY,$AMBIGUOUS)          //   but more than one key is carried,
    PROMPT(32)                         //   then set prompt to "Which key?"
  ELSE
    AT($HALL)                          // Otherwise: If at hall, toilet is not
    ZERO($TOILET_OPENED)               //   opened, phrase WITH _key_ was not
    ISNULL($WHICH_KEY)                 //   given, then set prompt to
    PROMPT(33)                         //   "With what?"
  ELSE
    AT($HALL_2)                        // Second hall?
    ZERO($DOOR_OPENED)                 // Door not opened yet?
    EQ($WHICH_KEY,$LARGE_KEY)          // WITH (LARGE) KEY phrase was given?
    SET($DOOR_OPENED)                  // Well, open the toilet...
    OK
  ELSE
    AT($HALL_2)                        // Otherwise: If at hall2, door is not
    ZERO($DOOR_OPENED)                 //   opened, phrase WITH KEY was given,
    EQ($WHICH_KEY,$AMBIGUOUS)          //   but more than one key is carried,
    PROMPT(32)                         //   then set prompt to "Which key?"
  ELSE
    AT($HALL_2)                        // Otherwise: If at hall2, door is not
    ZERO($DOOR_OPENED)                 //   opened, phrase WITH _key_ was not
    ISNULL($WHICH_KEY)                 //   given, then set prompt to
    PROMPT(33)                         //   "With what?"
    
ACTION(CLOSE,CUPBOARD)
    PRESENT($OP_CUPBOARD)              // Open cupboard (first one) is here?
    SWAP($CL_CUPBOARD,$OP_CUPBOARD)    // Well, close it...
    DESTROY($CL_SAFE)                  // Hide the safe, regardless of whether
    DESTROY($OP_SAFE)                  //   it is open or closed
    DESC                               // Redescribe
  ELSE
    PRESENT($OP_CUPB_2)                // Open cupboard (anohter one) is here?
    SWAP($CL_CUPB_2,$OP_CUPB_2)        // Close it...
    DESC                               // Redescribe

ACTION(CLOSE,SAFE)
    PRESENT($OP_SAFE)                  // Open safe is here?
    SWAP($CL_SAFE,$OP_SAFE)            // Close it...
    DESC                               // Redescribe

ACTION(CLOSE,FRIDGE)
    PRESENT($OP_FRIDGE)                // Open fridge is here?
    SWAP($CL_FRIDGE,$OP_FRIDGE)        // Close it...
    DESC                               // Redescribe

ACTION(CLOSE,TOILET)
    AT($HALL)                          // Hall?
    SETNOUN(DOOR)                      // Turn CLOSE TOILET into CLOSE DOOR

ACTION(CLOSE,DOOR)
    AT($HALL)                          // Hall?
    NOTZERO($TOILET_OPENED)            // Toilet opened?
    CLEAR($TOILET_OPENED)              // Close it
    OK
  ELSE
    AT($HALL_2)                        // Second hall?
    NOTZERO($DOOR_OPENED)              // Door opened?
    CLEAR($DOOR_OPENED)                // Close it
    OK

ACTION(GET,I)
    INVEN

// The player can type GET IRON KEY, GET SMALL KEY and GET LARGE KEY (or even
// GET IRON, GET SMALL and GET LARGE) to pick up a particular key, but we want
// to allow player to type simply GET KEY, except in ambiguous situations...

ACTION(GET,KEY)
    HERE($IRON_KEY)                    // Handle ambiguous situations, when
    HERE($SMALL_KEY)                   //   more different keys are here
    PROMPT(32)                         // Set prompt to "Which key?"
    DONE
  ELSE
    HERE($IRON_KEY)                    // Yet one ambiguity...
    HERE($LARGE_KEY)
    PROMPT(32)                         // "Which key?" prompt
    DONE
  ELSE
    HERE($SMALL_KEY)                   // Yet one ambiguity...
    HERE($LARGE_KEY)
    PROMPT(32)                         // "Which key?" prompt
    DONE
  ELSE
    HERE($IRON_KEY)                    // Now, there is no any ambiguity, so
    SETNOUN(IRON)                      //   set the appropriate adjective and
  ELSE                                 //   continue through AUTOG action...
    HERE($SMALL_KEY)
    SETNOUN(SMALL)
  ELSE
    HERE($LARGE_KEY)
    SETNOUN(LARGE)

ACTION(GET,_)
    AUTOG                              // Automatic get...
    OK

// The player can type DROP IRON KEY, DROP SMALL KEY and DROP LARGE KEY (or
// even DROP IRON, DROP SMALL and DROP LARGE) to drop a particular key, but we 
// want to allow typing simply DROP KEY, except in ambiguous situations...
       
ACTION(DROP,KEY)
    CARRIED($IRON_KEY)                 // Handle ambiguous situations, when
    CARRIED($SMALL_KEY)                //   more different keys are carried...
    PROMPT(32)                         // Set prompt to "Which key?"
    DONE
  ELSE
    CARRIED($IRON_KEY)                 // Yet one ambiguity...
    CARRIED($LARGE_KEY)
    PROMPT(32)                         // "Which key?" prompt
    DONE
  ELSE
    CARRIED($SMALL_KEY)                // Yet one ambiguity...
    CARRIED($LARGE_KEY)
    PROMPT(32)                         // "Which key?" prompt
    DONE
  ELSE
    PRESENT($IRON_KEY)                 // Now, there is no any ambiguity, so
    SETNOUN(IRON)                      //   set the appropriate adjective and
  ELSE                                 //   continue through AUTOD action...
    PRESENT($SMALL_KEY)
    SETNOUN(SMALL)
  ELSE
    PRESENT($LARGE_KEY)
    SETNOUN(LARGE)
    
ACTION(DROP,_)
    AUTOD                              // Automatic drop...
    OK

ACTION(WEAR,CLOTHES)
    WEAR($CLOTHES)                     // Wear clothes, if possible
    OK

ACTION(REMOVE,CLOTHES)
    REMOVE($CLOTHES)                   // Remove clothes, if possible
    OK

// And, finally, some very common actions...
    
ACTION(I,_)
    INVEN
    
ACTION(R,_)
    DESC
    
ACTION(QUIT,_)
    QUIT
    NEWLINE
    SCORE
    TURNS
    END
    
ACTION(SAVE,_)
    SAVE
    
ACTION(LOAD,_)
    LOAD

$$PICTURES

// +------------------+
// | Pictures Section |
// +------------------+

// No pictures in this game...

$$EXTERN

// +------------------+
// | External Section |
// +------------------+

// No external modules...

$$END
