// The demonstration game for The Quill Adventure Writer by Zeljko Juric.
// Originally written by CyberDaemon (Vladimir Krstulja) in C language for PC.
// Slightly improved and ported to The Quill (TI version) by Zeljko Juric.

// This game is a coding example, which illustrates some more advanced coding
// tricks, like random events, full text scrolling, implementing of mazes, 
// usage of scenery objects and coding automatic actions for them, bypassing
// the default interpreter responses to make messages in the game less
// stereotype, etc.

$$TITLE("The Island")

// +-----------------+
// | Aliases Section |
// +-----------------+

// Locations aliases

DEFINE(INTRO,0)
DEFINE(CLEARING,1)
DEFINE(FOREST1,2)
DEFINE(FOREST2,3)
DEFINE(FOREST3,4)
DEFINE(SHORE,5)
DEFINE(IN_BOAT,6)
DEFINE(PATH1,7)
DEFINE(PATH2,8)
DEFINE(VILLAGE,9)
DEFINE(IN_HOUSE,10)
DEFINE(MOUNTAINS,11)
DEFINE(TOP,12)
DEFINE(CAVEMOUTH,13)
DEFINE(CAVE,14)
DEFINE(PATHWAY,15)
DEFINE(LEDGE,16)

// Objects aliases

DEFINE(ENGINE,0)
DEFINE(KEY,1)
DEFINE(CAN,2)
DEFINE(FOOD,3)
DEFINE(SHOVEL,4)
DEFINE(CUP,5)
DEFINE(STICK,6)
DEFINE(PAPER,7)
DEFINE(CHEST,8)
DEFINE(AIRPLANE,9)
DEFINE(HOUSE,10)
DEFINE(BOAT,11)
DEFINE(SAND,12)
DEFINE(SIGN,13)
DEFINE(GRAVE,14)
DEFINE(DOOR,15)
DEFINE(TABLE,16)

// Flags aliases

DEFINE(SAND_STATE,11)                  // How deep is the hole in the sand
DEFINE(CHEST_STATE,12)                 // LOCKED, CLOSED or OPENED
DEFINE(DOOR_OPENED,13)                 // Nonzero if the door is opened
DEFINE(CAN_OPENED,14)                  // Nonzero if the can is opened
DEFINE(OBJ_NUM,15)                     // Number of the referenced object
DEFINE(OBJ_LOC,16)                     // Location of the referenced object
DEFINE(LAST_EVENT,17)                  // Keeps the last random event

// Other aliases

DEFINE(LOCKED,0)                       // Chest is locked
DEFINE(CLOSED,1)                       // Chest is closed
DEFINE(OPENED,2)                       // Chest is opened

$$VOCABULARY(4)

// +--------------------+
// | Vocabulary Section |
// +--------------------+

// Here, the vocabulary is organized well, i.e. verbs, nouns etc. are 
// separated, which allows making the parser a bit more inteligent

// Movement words

WORD(1,N)                     
WORD(1,NORTH)
WORD(2,S)
WORD(2,SOUTH)
WORD(3,E)
WORD(3,EAST)
WORD(4,W)
WORD(4,WEST)

// Ordinary nouns

WORD(20,ENGINE)
WORD(21,KEY)
WORD(22,CAN)
WORD(23,FUEL)
WORD(24,FOOD)
WORD(25,SHOVEL)
WORD(26,CUP)
WORD(27,STICK)
WORD(28,PAPER)
WORD(29,CHEST)
WORD(30,AIRPLANE)
WORD(30,PLANE)
WORD(31,HOUSE)
WORD(32,BOAT)
WORD(33,SAND)
WORD(34,DOOR)
WORD(35,SIGN)
WORD(36,GRAVE)
WORD(37,TABLE)
WORD(38,DAEMON)

// A special word

WORD(50,DEATHMATCH)

// Verbs

WORD(100,GET)
WORD(100,TAKE)
WORD(100,PICK)
WORD(101,DROP)
WORD(101,LEAVE)
WORD(101,PUT)
WORD(101,THROW)
WORD(104,I)
WORD(104,INVENTORY)
WORD(105,R)
WORD(105,REDESCRIBE)
WORD(106,QUIT)
WORD(106,STOP)
WORD(107,SAVE)
WORD(108,LOAD)
WORD(108,RESTORE)
WORD(109,EXAMINE)
WORD(109,SEARCH)
WORD(110,DIG)
WORD(111,OPEN)
WORD(112,CLOSE)
WORD(113,UNLOCK)
WORD(114,READ)
WORD(115,START)
WORD(116,TURN)
WORD(117,ENTER)
WORD(118,L)
WORD(118,LOOK)
WORD(119,SAY)
WORD(120,HELP)

$$LOCATIONS

// +-------------------+
// | Locations Section |
// +-------------------+

// Here is implemented a simple and small maze: there are three different
// locations with the same description. Don't worry about wasting space if
// you want to have 15 locations with the same description: this will be
// optimized by the compiler...

LOC($INTRO,"The Island\n---------\n\n"
    "You must get away from the island. There is a small boat at the shore "
    "with an engine inside it. All you have to do is to START THE ENGINE, "
    "but to do that you need to have fuel can and some ... in your "
    "inventory or aboard...\n"
    "Type HELP if you are stuck...\n\n"
    "Original by CyberDaemon (Vladimir Krstulja)\n"
    "Adapted for The Quill by Zeljko Juric")
LOC($CLEARING,"Small clearing\n-------------\n\n"
    "You are on a small clearing. Here is your crashed plane, and you can see "
    "woods all around. There is a small path leading into the woods to the "
    "west and you can see a small sign by the path.")
LOC($FOREST1,"Forest\n------\n\n"
    "You are lost in a wood. There are trees all around you.")
LOC($FOREST2,"Forest\n------\n\n"
    "You are lost in a wood. There are trees all around you.")
LOC($FOREST3,"Forest\n------\n\n"
    "You are lost in a wood. There are trees all around you.")
LOC($SHORE,"Sandy shore\n----------\n\n"
    "You are on a shore. There is a small boat in the sea to the south, and "
    "there a pathway can be seen to the north. You can hear sounds of sea "
    "splashing off the shore. You stand on a yellow and hot sand that burns "
    "on your feet. This reminded you on those Pirate Gold films you were "
    "watching at home.")
LOC($IN_BOAT,"In the boat\n---------\n\n"
    "You are in a small boat. You can see and hear a sea splashing off the "
    "shore.")
LOC($PATH1,"Forest path\n----------\n\n"
    "This is a small path in the wood that runs from north to south. To the "
    "south sounds of sea can be heard, and you can see some buildings to the "
    "north. The wood is here less frequent.")
LOC($PATH2,"Forest path\n----------\n\n"
    "You are on a a small path in the wood that continues to the north and to "
    "the south. To the north you can see a small village, and to the south "
    "you can hear the sounds of sea.")
LOC($VILLAGE,"In the village\n-----------\n\n"
    "This is a native village on the small clearing sorrounded by wood. Here, "
    "you can see some houses all made of bamboo wood and an old house made of "
    "solid rock to the east. Yet, although village looks habitable, there is "
    "nobody here. You can see a rocky ledge to the west, and a distant "
    "mountain to the north. There is a path running into the woods to the "
    "south.")
LOC($IN_HOUSE,"In the old house\n-------------\n\n"
    "You are in an old house. From the ceiling, an oil lamp gives some light. "
    "The house contains only one room with no windows and one door to the "
    "west. The walls are old and rusty, and you can feel the moisture in the "
    "air. There is a table in the middle of the room.")
LOC($MOUNTAINS,"Mountain side\n-----------\n\n"
    "You are on a path that runs up in mountain to the north. You can see a "
    "village surrounded by woods to the south.")
LOC($TOP,"Mountain side\n-----------\n\n"
    "This is an end of a path that leads from the village. You are high up "
    "here so you can see the whole island. There is a sea surrounding the "
    "small island on which you are. You can also see a small rocky ledge down "
    "there. To the north you can see an entrance to the cave, and a high top "
    "of the mountain.")
LOC($CAVEMOUTH,"Cave mouth\n----------\n\n"
    "You are in front of an entrance to the cave to the north. There is a "
    "path going down to the south.")
LOC($CAVE,"In the cave\n---------\n\n"
    "You are in the small cave. Here, you can see a golden chest up to the "
    "wall and an exit leading south. You can hear drops of water from "
    "somewhere.")
LOC($PATHWAY,"Cliff path\n--------\n\n"
    "This is a small rocky pathway that leads to the ledge on the west. You "
    "can see a village to the east.")
LOC($LEDGE,"Rocky ledge\n----------\n\n"
    "You are on top of the rocky ledge. Here you can see a grave that "
    "speaks:\n\n"
	  "\"...Here lies CyberDaemon...\"\n\n"
	  "Looking around you can see woods far below, and a small village to the "
	  "east. To the north you can see a distant huge mountain. There is a chasm "
	  "all around you except the small path to the east.")

$$MESSAGES

// +------------------+
// | Messages Section |
// +------------------+

// It is good practice to define detailed object description messages (i.e.
// messages which would be displayed when the user tries to examine the 
// object)to have same numbers as object numbers. This make coding of 
// EXAMINE _object_ easier...

MSG($ENGINE,"It is a MERCURY 720 engine.")
MSG($KEY,"Looks exactly like yours house key.")
MSG($CAN,"It is a medium size green army fuel can.")
MSG($FOOD,"It smells like a fried chicken.")
MSG($SHOVEL,"It looks like a shovel that grave-diggers use.")
MSG($CUP,"Just an ordinary cup.")
MSG($STICK,"It has perhaps fallen from a tree.")
MSG($PAPER,"It is a computer paper. Something is written on it.")
MSG($CHEST,"The golden chest is locked.")
MSG($AIRPLANE,"WOW! An YF-22!!!")
MSG($HOUSE,"The house is rusty and old. With no windows, only a door.")
MSG($BOAT,"It is a military SCORPION speed boat.")
MSG($SAND,"It looks just like the sand.")
MSG($SIGN,"There is something written on it.")
MSG($GRAVE,"...Here lies CyberDaemon...")
MSG($DOOR,"Just a closed door.")
MSG($TABLE,"Just an ordinary table.")

// Other messages...

MSG(17,"You don't know how to swim. Besides, it's full of sharks.")
MSG(18,"Suddenly the CyberDaemon, the original coder of this game, pops out "
    "from the stack and tells you that you can't go that way.")
MSG(19,"You have obviously not read the sign, so you slip off the ledge and "
    "fall to your death.")
MSG(20,"\nYou can hear a splashing sound in the sea.")
MSG(21,"\nYou can hear a deep moaning sound.")
MSG(22,"\nYou can see yourself staring back at you.")
MSG(23,"\nYou can see mountain bulge in and out at the top.")
MSG(24,"\nYou turn around and see a whole bunch of daemons following you in "
    "silence.\n"
    "Don't LOOK AT DAEMONS because they are gone now...")
MSG(25,"\nSuddenly a bunch of daemons passes by you carrying a sign:\n\n"
    "\"We love CyberDaemon!\"")
MSG(26,"\nWAIT! I have to pop something from the stack...")
MSG(27,"Ok... Let's continue...")
MSG(28,"Please be more specific.")
MSG(29,"Where can you see that!?")
MSG(30,"You can't, the airplane has crashed.")
MSG(31,"The door is closed.")
MSG(32,"You can't enter in that. You better visit a psychiatrist.")
MSG(33,"No way! It will just spill arround.")
MSG(34,"It refuses to be moved.")
MSG(35,"Ok. Now you got it.")
MSG(37,"What a stupid idea! You can't dig that man!")
MSG(38,"You start digging with your hands, but soon you end up with a cute "
    "sand-castle... but the sea leveled it off.")
MSG(39,"You dig up some small holes. Boring.")
MSG(40,"As you approach to the grave to dig it, you can hear a demonic voice "
    "from the grave. You drop the shovel with fright.")
MSG(41,"You dig up a small hole in the sand.")
MSG(42,"You dig, and the hole in the sand becomes deeper.")
MSG(43,"You dig, and dig, and dig enough big hole to see a golden key in it.")
MSG(44,"You can't dig more deeper.")
MSG(45,"On the paper is written \"DEATHMATCH.\"")
MSG(46,"On the sign is written: \"Tourists! Take some food before leaving "
    "island...'")
MSG(47,"On the sign is written: \"Beware of falling over the ledge!\"")
MSG(48,"How can you read that!?")
MSG(49,"You can also see some food at the table.")
MSG(50,"The chest is locked.")
MSG(51,"You open a golden chest, and you see a small paper in it.")
MSG(52,"The chest is closed.")
MSG(53,"The golden chest is opened. There is a piece of paper in it.")
MSG(54,"The golden chest is already opened.")
MSG(55,"As you open an iron can the smell of fuel fills the air.")
MSG(56,"The iron can is already opened.")
MSG(57,"The iron door is already opened.")
MSG(58,"The gods won't let you...")
MSG(59,"As you approach the old house, there, a voice booms from somewhere:"
    "\n\n\"Do you know the code to enter the house???\"")
MSG(60,"The voice booms:\n\n"
    "\"Code invalid!!! Access denied!\"")
MSG(61,"The door bulges forward for few times and then opens.")
MSG(62,"You close a golden chest.")
MSG(63,"The golden chest is already closed.")
MSG(64,"You close an iron can, and the smell of fuel dissapears.")
MSG(65,"The iron can is already closed.")
MSG(66,"How can you close that!?")
MSG(67,"It smells like kerosine, and it is blue.")
MSG(68,"You unlock the golden chest.")
MSG(69,"You don't have the key to unlock it.")
MSG(70,"The chest is already unlocked.")
MSG(71,"The door has been locked from inside.")
MSG(72,"How can you unlock that!?")
MSG(73,"You kept turning that stuff for an hour and find nothing.")
MSG(74,"You can't. The airplane has crashed, remember?")
MSG(75,"You don't have the fuel to start it.")
MSG(76,"How can you start that!?")
MSG(77,"You put the fuel into the engine, start it, and hit the road to "
    "somewhere...")
MSG(78,"\nYou were wandering around on sea for few days, and then you died "
    "of hunger.")
MSG(79,"\nCongratulations!!!\n\n"
    "You have finished the game, and you have proved yourself to be an "
    "adventurist. Now you can play some more seriously adventure games, or "
    "why don't code a your own adventure game by yourself!?\n\n"
    "Thanks for playing The Island...")
MSG(80,"Hmmm... This sentence does not begin with a verb known to me...")
MSG(81,"All what you have to do is to end this game. You have to input some "
    "orders like GET, LOOK, OPEN, and so on.\n\n"
    "If you want to move through the island, just input one of four "
    "directions:\n\n"
    "- to go north input N\n"
    "- to go south input S\n"
    "- to go east input E\n"
    "- to go west input W\n\n"
    "To see what are you carrying input I or INVENTORY. To quit the game "
    "input QUIT. The rest is on program to do.")
MSG(82,"To find a path through the forest, drop something before enter a "
    "direction. If the object is still there, you have returned to the same "
    "location...")
MSG(83,"Ok, ok, if you are so lazy, this is the map: if I were lazy, this "
    "game would not be here, he he...")
MSG(84,"There are too many verbs in this sentence.")
MSG(85,"Enter it first!")

$$SYSTEM_MESSAGES

// +-------------------------+
// | System Messages Section |
// +-------------------------+

MSG(1,"\nNear to your hands you can see:")
MSG(2,"\nWhat next?")
MSG(3,"\nEnter the code:")
MSG(6,"I don't understand any words in this sentence.")
MSG(7,"The forest is unpassable unless you are the coder of this game to make "
    "it passable...")
MSG(8,"You cannot do that.")
MSG(9,"You have:")
MSG(11,"Nothing... Expect your sanity...")
MSG(12,"Do you really want to quit now?")
MSG(13,"\nThe game is over. Play again?")
MSG(14,"\nPress any key to exit.")
MSG(15,"Ok. Now you droped it.")
MSG(16,"\nPress any key to continue.")
MSG(25,"You already have that.")
MSG(26,"You can't see that here.")
MSG(27,"You are carrying too much.")
MSG(28,"How can you drop something you don't even have!?")
MSG(30,"Y")
MSG(31,"N")

$$OBJECTS(4)                           // The player can carry 4 objects

// +-----------------+
// | Objects Section |
// +-----------------+

OBJ($ENGINE,"A heavy engine.",ENGINE,$IN_BOAT)
OBJ($KEY,"A golden key.",KEY,$NOWHERE)
OBJ($CAN,"An iron can.",CAN,$IN_HOUSE)
OBJ($FOOD,"Some food.",FOOD,$NOWHERE)
OBJ($SHOVEL,"A shovel.",SHOVEL,$LEDGE)
OBJ($CUP,"A plastic cup.",CUP,$CLEARING)
OBJ($STICK,"A wooden stick.",STICK,$CLEARING)
OBJ($PAPER,"A small paper.",PAPER,$NOWHERE)

// Scenery objects are items which are mentioned in the location descriptions,
// but which are not coded as objects in the QADL source. That's why automatic
// actions coded using WHATO command can not be applied to them. However, it
// is possible to perform automatic actions to scenery objects too. To achieve
// this, scenery objects should to be inserted in the Objects Section as
// entries without names. Such entries will not be listed when the location is
// described (more precise, when the LISTOBJ command is executed).

OBJ($CHEST,"",CHEST,$CAVE)
OBJ($AIRPLANE,"",AIRPLANE,$CLEARING)
OBJ($HOUSE,"",HOUSE,$VILLAGE)
OBJ($BOAT,"",BOAT,$SHORE)
OBJ($SAND,"",SAND,$SHORE)
OBJ($SIGN,"",SIGN,$CLEARING)
OBJ($GRAVE,"",GRAVE,$LEDGE)
OBJ($DOOR,"",DOOR,$VILLAGE)
OBJ($TABLE,"",TABLE,$IN_HOUSE)

$$CONNECTIONS

// +---------------------+
// | Connections Section |
// +---------------------+

FROM($CLEARING)
    CONN(W,$FOREST1)
    
FROM($FOREST1)
    CONN(N,$FOREST1)
    CONN(S,$FOREST2)
    CONN(E,$CLEARING)
    CONN(W,$FOREST1)
    
FROM($FOREST2)
    CONN(N,$FOREST1)
    CONN(S,$FOREST3)
    CONN(E,$FOREST2)
    CONN(W,$FOREST2)
    
FROM($FOREST3)
    CONN(N,$FOREST2)
    CONN(S,$FOREST3)
    CONN(E,$FOREST3)
    CONN(W,$SHORE)
    
FROM($SHORE)
    CONN(N,$PATH1)
    CONN(S,$IN_BOAT)
    CONN(E,$FOREST3)
    
FROM($IN_BOAT)
    CONN(N,$SHORE)

FROM($PATH1)
    CONN(N,$PATH2)
    CONN(S,$SHORE)
    
FROM($PATH2)
    CONN(N,$VILLAGE)
    CONN(S,$PATH1)
    
FROM($VILLAGE)
    CONN(N,$MOUNTAINS)
    CONN(S,$PATH2)
    CONN(W,$PATHWAY)
    
FROM($IN_HOUSE)
    CONN(W,$VILLAGE)

FROM($MOUNTAINS)
    CONN(N,$TOP)
    CONN(S,$VILLAGE)

FROM($TOP)
    CONN(N,$CAVEMOUTH)
    CONN(S,$MOUNTAINS)

FROM($CAVEMOUTH)
    CONN(N,$CAVE)
    CONN(S,$TOP)

FROM($CAVE)
    CONN(S,$CAVEMOUTH)

FROM($PATHWAY)
    CONN(E,$VILLAGE)
    CONN(W,$LEDGE)

FROM($LEDGE)
    CONN(E,$PATHWAY)

$$EVENTS

// +----------------+
// | Events Section |
// +----------------+

// Note that the CLS command is removed from the "standard" location 
// description entry. This make the game a full-screen text scrolling game.

EVENT
    ISDESC                             // Description in progress?
    SHOWLOC                            // Display the location
    NEWLINE
    LISTOBJ                            // List objects

EVENT
    AT($INTRO)                         // Intro screen?
    ANYKEY                             // Wait for a keypress...
    CLS                                // Clear the screen
    PROMPT(2)                          // Always "What now?" prompt
    GOTO($CLEARING)                    // The game starts at the clearing
    DESC                               // Describe the new location

// There are two signs in the game, one at the clearing, and another one at
// the ledge. They are coded as just one scenery object (which "moves" 
// arround), to make coding some automatic actions easier.

EVENT
    AT($CLEARING)                      // Clearing?
    CREATE($SIGN)                      // Create a sign here
    
EVENT
    AT($LEDGE)                         // Ledge?
    CREATE($SIGN)                      // Create a sign here

// Similarly, the boat (another scenery object) is accesible either when you
// are in front of it, or when you are in it...

EVENT
    AT($SHORE)                         // Shore?
    CREATE($BOAT)                      // A boat is here...
    
EVENT
    AT($IN_BOAT)                       // In boat?
    CREATE($BOAT)                      // Also here...

// Now follows coding of some funny random events, to make the game more 
// interesting. Each time when an event happens, its ID number is saved, in
// the variable $LAST_EVENT. It is checked to avoid consecutive apperance of
// the same events twice...

EVENT
    LT($TURNLO,5)                      // Less than 5 turns from the begining
    ZERO($TURNHI)                      //   of the game?
    DONE                               // No random events before...

EVENT
    NOTEQ($LAST_EVENT,1)
    ATGT($FOREST3)                     // Shore or boat?
    ATLT($PATH1)
    CHANCE(10)                         // Chance of 10%?
    MESSAGE(20)                        // Splashing sound...
    LET($LAST_EVENT,1)
    
EVENT
    NOTEQ($LAST_EVENT,2)
    ATGT($CLEARING)                    // Somewhere in the forest?
    ATLT($SHORE)
    CHANCE(10)                         // Chance of 10%?
    MESSAGE(21)                        // Moaning sound...
    LET($LAST_EVENT,2)
    
EVENT
    NOTEQ($LAST_EVENT,3)
    ATGT($MOUNTAINS)                   // Somewhere arround the village?
    NOTAT($CAVE)
    CHANCE(7)                          // Chance of 7%?
    MESSAGE(22)                        // Staring back...    
    LET($LAST_EVENT,3)
    
EVENT
    NOTEQ($LAST_EVENT,3)
    AT($VILLAGE)                       // In the village?
    CHANCE(7)                          // Chance of 7%?
    MESSAGE(22)                        // Staring back...    
    LET($LAST_EVENT,3)

EVENT
    NOTEQ($LAST_EVENT,4)
    ATGT($IN_HOUSE)                    // Somewhere in mountains?
    ATLT($CAVE)
    CHANCE(10)                         // Chance of 10%?
    MESSAGE(23)                        // Mountain bulge...
    LET($LAST_EVENT,4)

EVENT
    NOTEQ($LAST_EVENT,5)
    CHANCE(5)                          // Chance of 5%?
    MESSAGE(24)                        // Daemons...
    LET($LAST_EVENT,5)
    
EVENT
    NOTEQ($LAST_EVENT,6)
    ATGT($SHORE)                       // Somewhere on the path?
    ATLT($VILLAGE)
    CHANCE(20)                         // Chance of 20%
    MESSAGE(25)                        // Daemons with a propaganda...
    LET($LAST_EVENT,6)
    
EVENT
    NOTEQ($LAST_EVENT,7)
    CHANCE(5)                          // Chance of 5%?
    MESSAGE(26)
    PAUSE(100)                         // "Pop-ing from the stack" joke...
    MESSAGE(27)
    PAUSE(100)
    LET($LAST_EVENT,7)    
    
$$ACTIONS

// +-----------------+
// | Actions Section |
// +-----------------+

// Valid responses to "Enter the code:" prompt...

ACTION(SAY,DEATHMATCH)
    SETVERB(DEATHMATCH)                // Accept SAY DEATHMATCH as well as
    CANCEL                             //   just DEATHMATCH...

ACTION(DEATHMATCH,_)
    EQ($PROMPT,3)                      // "Enter the code:" prompt?
    PROMPT(2)                          // Restore the "What now?" prompt
    SET($DOOR_OPENED)                  // Open the door
    MESSAGE(61)                        // The door opens...
    DONE

// Any other response to "Enter the code:" is not valid in this game...

ACTION(_,_)
    EQ($PROMPT,3)                      // "Enter the code:" prompt?
    PROMPT(2)                          // Restore the "What now?" prompt
    MESSAGE(60)                        // Invalid code...
    DONE

// Process standard movements...

ACTION(_,_)
    TRYMOVE                            // Try to perform standard movements
    DESC                               //   through the Connections Section

// Forbidden movements which does not cause the standard SM7 response...

ACTION(_,_)
    LT($VERB,5)                        // A movement word?
    AT($IN_HOUSE)                      // In house?
    MESSAGE(18)                        // CyberDaemon joke...
    DONE
  ELSE
    LT($VERB,5)                        // A movement word?  
    AT($CAVE)                          // In cave?
    MESSAGE(18)                        // CyberDaemon joke...
    DONE
  ELSE
    LT($VERB,5)                        // A movement word?    
    AT($IN_BOAT)                       // In boat?
    MESSAGE(17)                        // You don't know how to swim...
    DONE
  ELSE
    LT($VERB,5)                        // A movement word?      
    AT($LEDGE)                         // Ledge?
    MESSAGE(19)                        // You fall...
    END                                // Bad luck!

// Going east from the village (to enter the house) is allowed only if the
// door is opened...

ACTION(E,_)
    AT($VILLAGE)                       // Village?
    NOTZERO($DOOR_OPENED)              // Door open?
    GOTO($HOUSE)                       // Well, enter the house...
    DESC                               // Redescribe
  ELSE
    AT($VILLAGE)                       // Otherwise: Village (door not open)?
    MESSAGE(31)                        // The door is closed...
    DONE

// Any other invalid movements should produce the standard response. This is
// just the default behaviour of the interpreter, but it will be coded here
// explicitely, to avoid problems which may appear if some of the illegal
// movements is catched in some ACTION(_,_) entry...

ACTION(_,_)
    LT($VERB,5)                        // A movement word?
    NOTDONE                            // Forest is unpassable...

// We want to make LOOK equal to REDESCRIBE, but LOOK _object_ equal to
// EXAMINE _object_ ...
    
ACTION(LOOK,_)
    SETVERB(REDESCRIBE)                // Set verb to REDESCRIBE
    ISNOTNULL($NOUN)                   // Noun recognized?
    SETVERB(EXAMINE)                   // If it is, set verb to EXAMINE
  CONTINUE
    CANCEL                             // Signal "nothing concrete so far..."

// Some very common entries...

ACTION(GET,I)
    INVEN
    
ACTION(I,_)
    INVEN
    
ACTION(R,_)
    DESC
    
ACTION(QUIT,_)
    QUIT 
    END
    
ACTION(SAVE,_)
    SAVE
    
ACTION(LOAD,_)
    LOAD

ACTION(HELP,_)
    AT($CLEARING)                      // Clearing?
    CLS                                // Clear the screen
    MESSAGE(81)                        // Basic info about the game...
    DONE
  ELSE
    ATLT($SHORE)                       // Somewhere in the forest?
    MESSAGE(82)                        // A forest hint...
    DONE
  ELSE
    MESSAGE(83)                        // You are too lazy...
    DONE

ACTION(TURN,_)
    MESSAGE(73)                        // Nothing useful...
    DONE
   
// Note that responses to all sentences which may be given without a noun must
// be coded (and finished with DONE or something similar) before this entry, 
// which checks the "gramarry" of the typed sentence, and if it is "good", 
// extracts some parameters about the currently referenced object.

ACTION(_,_)
    LT($VERB,100)                      // Not a verb?
    MESSAGE(80)                        // No verbs in the sentence...
    DONE
  ELSE
    ISNULL($NOUN)                      // No noun?
    MESSAGE(28)                        // Be more specific...
    DONE
  ELSE
    GT($NOUN,99)                       // A verb instead of noun?
    MESSAGE(84)                        // Too many verbs in the sentence...
    DONE
  ELSE
    WHATO($OBJ_NUM)                    // What is the object...
    LET($OBJ_LOC,$NOWHERE)             // Non-recognized objects are nowhere
    ISNOTNULL($OBJ_NUM)                // Object recognized?
    WHEREO($OBJ_NUM,$OBJ_LOC)          // If it is, find where is it...
  CONTINUE  
    CANCEL                             // Signal "nothing concrete"...

// Examining...

ACTION(EXAMINE,FUEL)
    PRESENT($CAN)                      // The can is available?
    NOTZERO($CAN_OPENED)               // The can is open?
    MESSAGE(67)                        // It smells...
    DONE    
    
ACTION(EXAMINE,_)
    NOTEQ($OBJ_LOC,$CARRIED)           // Referenced object not carried?
    NOTSAME($OBJ_LOC,$CURLOC)          // Referenced object is not here?
    SYSMESS(26)                        // You can't see that here
    NEWLINE
    DONE

ACTION(EXAMINE,CHEST)
    EQ($CHEST_STATE,$CLOSED)           // Display an appropriate message
    MESSAGE(52)                        //   depending of whether the chest is
    DONE                               //   closed or opened (note that if the
  ELSE                                 //   chest is locked, the scanning 
    EQ($CHEST_STATE,$OPENED)           //   continues further through the next
    MESSAGE(53)                        //   entry)
    DONE

// Automatic action for examining all other available objects (using MESFLAG
// command). Note that a default message associated with the chest tells that
// it is locked...

ACTION(EXAMINE,_)
    MESFLAG($OBJ_NUM)                  // Display the related message followed
    NEWLINE                            //   by a newline then continue further
    
// Examining the table may have a side effect...
    
ACTION(EXAMINE,TABLE)
    NOTCREATED($FOOD)                  // Food not created yet?
    CREATE($FOOD)                      // Well, create it...    
    MESSAGE(49)                        // You see the food...

// Getting...

ACTION(GET,SAND)
    AT($SHORE)                         // Sandy shore?
    MESSAGE(33)                        // No chance...
    DONE
    
ACTION(GET,ENGINE)
    HERE($ENGINE)                      // Engine is here?
    MESSAGE(34)                        // It refuses to be moved...
    DONE
        
ACTION(GET,_)
    GT($OBJ_NUM,$PAPER)                // A scenery object?
    SAME($OBJ_LOC,$CURLOC)             // Here?
    MESSAGE(34)                        // It refuses to be moved...           
    DONE
  ELSE
    AUTOG                              // Perform an automatic get...
    MESSAGE(35)                        // Ok, you now have it...

// Dropping is extremely simple here...

ACTION(DROP,_)
    AUTOD                              // Perform an automatic get...
    OK                                 // Ok, you drop it...

// All following responses have sense only if the referenced object is
// available, so eliminate immidiately cases when it is not available.

ACTION(_,_)                            // No matter what...
    NOTEQ($OBJ_LOC,$CARRIED)           // Referenced object is not carried?
    NOTSAME($OBJ_LOC,$CURLOC)          // Referenced object is not here?
    MESSAGE(29)                        // Where can you see that!?
    DONE                               // Stop further scanning

// Now, we know that the referenced object is available, so there is no need
// for checking in following entries whether the object is available...

// Unlocking...

ACTION(UNLOCK,CHEST)
    EQ($CHEST_STATE,$LOCKED)           // Chest is locked?
    CARRIED($KEY)                      // Key carried?     
    LET($CHEST_STATE,$CLOSED)          // Well, unlock it?
    MESSAGE(68)                        // You unlock the chest...
    DONE
  ELSE
    EQ($CHEST_STATE,$LOCKED)           // Otherwise: Chest locked (no key)?
    MESSAGE(69)                        // You have not a key...
    DONE
  ELSE
    MESSAGE(70)                        // Already unlocked...
    DONE

ACTION(UNLOCK,DOOR)
    MESSAGE(71)                        // Locked from the other side...
    DONE

ACTION(UNLOCK,_)                       // UNLOCK anything else?
    MESSAGE(72)                        // How you can unlock that!?

// Opening...

ACTION(OPEN,CHEST)
    EQ($CHEST_STATE,$LOCKED)           // Chest is locked?
    MESSAGE(50)                        // No chance...
    DONE
  ELSE
    EQ($CHEST_STATE,$CLOSED)           // Chest is closed?
    LET($CHEST_STATE,$OPENED)          // Well, open it...
    CREATE($PAPER)                     // Create a paper
    MESSAGE(51)                        // You open chest and find a paper...
    DONE
  ELSE
    MESSAGE(54)                        // Already open...
    DONE

ACTION(OPEN,CAN)
    ZERO($CAN_OPENED)                  // Can is not open?
    SET($CAN_OPENED)                   // Well, open it...
    MESSAGE(55)                        // It smells...
    DONE
  ELSE
    MESSAGE(56)                        // Already open...
    DONE

ACTION(OPEN,DOOR)
    NOTZERO($DOOR_OPENED)              // Door is open?
    MESSAGE(57)                        // Already open...
    DONE
  ELSE
    MESSAGE(59)                        // Password please...
    PROMPT(3)                          // Set prompt to "Enter the code:"
    DONE
  
ACTION(OPEN,_)                         // OPEN anything else?
    MESSAGE(58)                        // Gods won't let you...

// Closing...

ACTION(CLOSE,CHEST)
    EQ($CHEST_STATE,$OPENED)           // Chest is open?
    LET($CHEST_STATE,$CLOSED)          // Well, close it...
    MESSAGE(62)                        // You close it...
  ELSE
    MESSAGE(63)                        // Already closed...
    DONE

ACTION(CLOSE,CAN)
    NOTZERO($CAN_OPENED)               // Can is open?
    CLEAR($CAN_OPENED)                 // Well, close it...
    MESSAGE(64)                        // You close it...
    DONE
  ELSE
    MESSAGE(65)                        // Already closed...
    DONE    

ACTION(CLOSE,_)                        // CLOSE anything else?
    MESSAGE(66)                        // How you can read that!?

// Entering...

ACTION(ENTER,PLANE)
    MESSAGE(30)                        // You can't, it is crashed...
    DONE
    
ACTION(ENTER,HOUSE)
    NOTZERO($DOOR_OPENED)              // Door is open?
    GOTO($IN_HOUSE)                    // Well, enter...
    DESC
  ELSE
    MESSAGE(31)                        // Closed...
    DONE
    
ACTION(ENTER,BOAT)
    GOTO($IN_BOAT)                     // Well, enter...
    DESC
    
ACTION(ENTER,_)                        // ENTER anything else?
    MESSAGE(32)                        // Nonsense...

// Digging...

ACTION(DIG,SAND)
    NOTCARR($SHOVEL)                   // Shovel not carried?
    MESSAGE(38)                        // You make a sand-castle...
    DONE
  ELSE
    PLUS($SAND_STATE,41)               // Messages which correspond to sand
    MESFLAG($SAND_STATE)               //   states 0,1,2 and 3 are 41,42,43 &
    NEWLINE                            //   44 respectively, so use a trick
    MINUS($SAND_STATE,41)              //   with MESFLAG to display them...
    EQ($SAND_STATE,2)                  // Hole deep enough?
    CREATE($KEY)                       // Create a golden key...
  CONTINUE
    NOTEQ($SAND_STATE,3)               // Maximal deep not reached?
    PLUS($SAND_STATE,1)                // Increase it...
  CONTINUE
    DONE
    
ACTION(DIG,GRAVE)
    NOTCARR($SHOVEL)                   // Shovel not carried?
    MESSAGE(39)                        // Inefficient...
    DONE
  ELSE
    MESSAGE(40)                        // A demonic voice...
    DROP($SHOVEL)                      // Drop the shovel...
    DONE
    
ACTION(DIG,_)                          // DIG anything else?
    MESSAGE(37)                        // A stupid idea...

// Reading...

ACTION(READ,PAPER)
    MESSAGE(45)                        // A secret code...
    DONE
    
ACTION(READ,SIGN)
    AT($CLEARING)                      // Clearing?
    MESSAGE(46)                        // A hint for a food...
    DONE
  ELSE
    AT($LEDGE)                         // Ledge?
    MESSAGE(47)                        // A hint for the ledge...
    DONE
    
ACTION(READ,_)                         // READ anything else?
    MESSAGE(48)                        // How you can read that!?

// Starting...

ACTION(START,AIRPLANE)
    MESSAGE(74)                        // Crashed...
    DONE

ACTION(START,BOAT)
    NOTAT($IN_BOAT)                    // Not in boat?
    MESSAGE(85)                        // Enter it first...
    DONE
  ELSE
    SETNOUN(ENGINE)                    // Turn START BOAT into START ENGINE
    
ACTION(START,ENGINE)
    NOTCARR($CAN)                      // The can not carried?
    MESSAGE(75)                        // You have no fuel...
    DONE
  ELSE
    ZERO($CAN_OPENED)                  // The can not open?
    MESSAGE(75)                        // Again, no fuel...
    DONE    
  ELSE
    CLS                                // Clear the screen
    MESSAGE(77)                        // You start the engine...
    NOTCARR($FOOD)                     // No food carried?
    MESSAGE(78)                        // Bad luck for you...
    END
  ELSE
    MESSAGE(79)                        // Well done!
    END
    
ACTION(START,_)                        // START anything else?
    MESSAGE(76)                        // How can you start that!?
    
$$PICTURES

// +------------------+
// | Pictures Section |
// +------------------+

// No pictures in this game...

$$EXTERN

// +------------------+
// | External Section |
// +------------------+

// No external modules...

$$END
