// The demonstration game for The Quill Adventure Writer by Zeljko Juric.
// Originally written by Graeme Yeandle and Tim J. Gilberts as a tutorial game
// for the Proffesional Adventure Writer for the ZX Spectrum by Gilsoft Ltd.
// Slightly improved and ported to The Quill (TI version) by Zeljko Juric.

// This game is a coding example, which illustrates some more advanced coding
// tricks, like usage of the bitmap pictures, implementation of container
// objects, coding of GET/DROP ALL actions, more realistic dropping actions,
// pseudo-inteligent non-player characters (a bird and a dog) which are not
// coded as objects, parsing of the speech to the non-player characters, etc.

$$TITLE("The Ticket")

// +-----------------+
// | Aliases Section |
// +-----------------+

// Locations aliases

DEFINE(INTRO,0)
DEFINE(IN_BAG,1)
DEFINE(BUSSTOP,2)
DEFINE(GRASS,3)
DEFINE(PATH,4)
DEFINE(BANDSTAND,5)
DEFINE(POND,6)
DEFINE(TREE,7)
DEFINE(UPTREE,8)
DEFINE(CELLAR,9)

// Objects aliases

DEFINE(LIT_TORCH,0)
DEFINE(BAG,1)
DEFINE(SANDWICH,2)
DEFINE(APPLE,3)
DEFINE(TICKET,4)
DEFINE(LEAD,5)
DEFINE(ANORAK,6)
DEFINE(UNLIT_TORCH,7)

// Flags aliases

DEFINE(BIRD_LOC,11)                    // Location where the bird is
DEFINE(DOG_LOC,12)                     // Location where the dog is
DEFINE(DOG_STATE,13)                   // Dog's state: see "Other aliases"
DEFINE(DOG_IS_SITTING,14)              // Nonzero if the dog is sitting
DEFINE(OBJ_NUM,15)                     // Number of the referenced object
DEFINE(OBJ_LOC,16)                     // Location of the referenced object
DEFINE(WORKING_WITH_BAG,17)            // Nonzero => get/put from/to the bag
DEFINE(SAVE_NUMCAR,18)                 // Temporary saves $NUMCAR
DEFINE(SAVE_CURLOC,19)                 // Temporary saves $CURLOC
DEFINE(THIRD_WORD,20)                  // Keeps the third recognized word
DEFINE(SPEECH_CHARACTER,21)            // The object of the speech
DEFINE(SPEECH_VERB,22)                 // The verb in the decoded speech
DEFINE(SPEECH_NOUN,23)                 // The noun in the decoded speech

// Other aliases

DEFINE(DOG_STANDARD,0)                 // Standard state of the dog
DEFINE(LEAD_ON_DOG,1)                  // The lead is on the dog
DEFINE(DOG_TIED,2)                     // The dog is tied

$$VOCABULARY(4)

// +--------------------+
// | Vocabulary Section |
// +--------------------+

WORD(1,N)
WORD(1,NORTH)
WORD(2,S)
WORD(2,SOUTH)
WORD(3,E)
WORD(3,EAST)
WORD(4,W)
WORD(4,WEST)
WORD(5,NE)
WORD(6,NW)
WORD(7,SE)
WORD(8,SW)
WORD(9,U)
WORD(9,UP)
WORD(9,CLIMB)
WORD(9,ASCEND)
WORD(10,D)
WORD(10,DOWN)
WORD(10,DESCEND)
WORD(100,GET)
WORD(100,TAKE)
WORD(101,DROP)
WORD(101,PUT)
WORD(102,REMOVE)
WORD(103,WEAR)
WORD(104,I)
WORD(104,INVENTORY)
WORD(105,R)
WORD(105,REDESCRIBE)
WORD(106,QUIT)
WORD(106,STOP)
WORD(107,SAVE)
WORD(108,LOAD)
WORD(109,RS)
WORD(109,RAMSAVE)
WORD(110,RL)
WORD(110,RAMLOAD)
WORD(111,LOOK)
WORD(111,EXAMINE)
WORD(112,SAY)
WORD(112,TALK)
WORD(112,SPEAK)
WORD(113,ASK)
WORD(114,SIT)
WORD(114,STAY)
WORD(115,COME)
WORD(115,HERE)
WORD(116,TIE)
WORD(117,UNTIE)
WORD(118,WAIT)
WORD(119,HELP)
WORD(119,HINT)
WORD(119,CLUE)
WORD(122,TORCH)
WORD(123,BAG)
WORD(124,SANDWICH)
WORD(125,APPLE)
WORD(126,BUS)
WORD(126,TICKET)
WORD(127,LEAD)
WORD(129,RAILING)
WORD(130,GRASS)
WORD(131,GATE)
WORD(131,PATH)
WORD(133,BENCH)
WORD(134,POND)
WORD(135,BANDS)
WORD(136,TREE)
WORD(137,LEAF)
WORD(137,BRANCH)
WORD(150,IN)
WORD(150,INTO)
WORD(151,OUT)
WORD(151,FROM)
WORD(152,ON)
WORD(152,ONTO)
WORD(152,LIGHT)
WORD(153,TO)
WORD(154,OFF)
WORD(154,EXTINGUISH)
WORD(170,BIRD)
WORD(171,DOG)
WORD(200,ANORAK)
WORD(250,ALL)

$$LOCATIONS

// +-------------------+
// | Locations Section |
// +-------------------+

LOC($INTRO,"THE TICKET\n\nWhile standing on the bus stop my bus ticket has "
    "been blown away, can you help me find it?")    
LOC($BUSSTOP,"I'm standing by a bus stop, on a road which runs North to South. "
    "To the West a park gate set in iron railings stands open.")
LOC($GRASS,"The grass on which I stand is neatly trimmed. To the North is a "
    "path and bench while to the West is an ornamental pond.")
LOC($PATH,"I am on a gravel path running East to West, by a park bench, to the "
    "South is a grassy area while to the North I can see a bandstand.")
LOC($BANDSTAND,"I am standing on the bandstand which appears to be made of "
    "ornate cast iron painted white. To the South is a path. Below the "
    "bandstand is a cellar.")
LOC($POND,"The sun glitters on the surface of the ornamental pond, whose "
    "waters ripple in the gentle breeze. A path runs North towards a large "
    "tree, while to East is a grassy area.")
LOC($TREE,"The path curves South and East here beside a large tree.")
LOC($UPTREE,"I am sitting on a branch in a broad leaved tree, the park is "
    "spread out before me, to the East I can see the bus stop through the gate "
    "in the railings.")
LOC($CELLAR,"I'm in a dark and wet cellar below the bandstand.")

$$MESSAGES

// +------------------+
// | Messages Section |
// +------------------+

MSG(0,"The apple is crisp and green.")
MSG(1,"It's a cheese and pickle sandwich.")
MSG(2,"The ticket has \"City Bus Company\" printed on it.")
MSG(3,"The bench is firmly screwed to a concrete base.")
MSG(4,"\nThe bus arrives. I hand the ticket to the driver who smiles and says "
    "\"Sorry I'm late, hope you haven't been standing too long?\"")
MSG(5,"In the bag is:")
MSG(6,"The bird drops the ticket to peck at the sandwich.")
MSG(7,"The bird snatches the ticket.")
MSG(8,"The bird ignores me.")
MSG(9,"A small bird is here.")
MSG(10,"The bird has a ticket in its beak.")
MSG(11,"A small bird settles on the ground.")
MSG(12,"A small bird lands on the branch.")
MSG(13,"The bird sees the dog and flutters away quickly.")
MSG(14,"The bird flies away.")
MSG(15,"It falls to the ground at the foot of the tree.")
MSG(16,"The dog's bright eyes stare at me with mindless love.")
MSG(17,"A dog is here.")
MSG(18,"The dog follows me wagging his tail.")
MSG(19,"A lead trails behind the dog.")
MSG(20,"The dog is tied to the bench by a lead.")
MSG(21,"Trustingly the dog lets me put the lead around its neck.")
MSG(22,"I've tied the lead to the bench.")
MSG(23,"Who should I say it to!?")
MSG(24,"The dog is sitting quietly.")
MSG(25,"I've untied the dog from the bench.")
MSG(26,"There is no any bag here.")
MSG(27,"It is not in the bag.")
MSG(28,"I must remove it first.")
MSG(29,"Time passes...")
MSG(30,"I don't see anything special.")
MSG(31,"An ordinary hand bag. Maybe I should look in it?")
MSG(32,"I can't see anything to take.")
MSG(33,"My hands are empty.")
MSG(34,"You should to put a lead on the dog first.")
MSG(35,"Please be a bit more concrete.")
MSG(36,"You probably have problems with a dog... Well, it surely will not "
    "follow you up to the tree. And, have you tried to tie it somewhere, or "
    "simply to ask it to stay here?")

$$SYSTEM_MESSAGES

// +-------------------------+
// | System Messages Section |
// +-------------------------+

MSG(0,"It's too dark to see anything.")
MSG(1,"I can also see:")
MSG(2,"\nWhat now?")
MSG(3,"\nWhat next?")
MSG(4,"\nWhat should I do now?")
MSG(5,"\nWhat should I do next?")
MSG(6,"I was not able to understand any of that. Please try again.")
MSG(7,"I can't go in that direction.")
MSG(8,"I can't do that.")
MSG(9,"I have with me:")
MSG(10," (worn)")
MSG(11,"Nothing at all.")
MSG(12,"Are you sure?")
MSG(13,"Would you like another go?")
MSG(14,"\nGoodbye...")
MSG(15,"OK.")
MSG(16,"\nPress any key to continue.")
MSG(17,"\nYou have taken ")
MSG(18," turn")
MSG(19,"s")
MSG(20,".")
MSG(21,"You have scored ")
MSG(22,"%")
MSG(23,"I'm not wearing one of those.")
MSG(24,"I can't. My hands are full.")
MSG(25,"I already have it.")
MSG(26,"There isn't one of those here.")
MSG(27,"I can't carry any more things.")
MSG(28,"I don't have one of those.")
MSG(29,"I'm already wearing it.")
MSG(30,"Y")
MSG(31,"N")

$$OBJECTS(3)                           // The player can carry 3 objects

// +-----------------+
// | Objects Section |
// +-----------------+

OBJ($LIT_TORCH,"A lit torch.",_,$NOWHERE)
OBJ($BAG,"A bag.",BAG,2)
OBJ($SANDWICH,"A sandwich.",SANDWICH,1)
OBJ($APPLE,"An apple.",APPLE,$CARRIED)
OBJ($TICKET,"A ticket.",TICKET,8)
OBJ($LEAD,"A lead.",LEAD,9)
OBJ($ANORAK,"An anorak.",ANORAK,$WORN)
OBJ($UNLIT_TORCH,"An unlit torch.",TORCH,1)

$$CONNECTIONS

// +---------------------+
// | Connections Section |
// +---------------------+

FROM($BUSSTOP)
    CONN(W,$PATH)
    
FROM($GRASS)
    CONN(N,$PATH)
    CONN(W,$POND)
    CONN(NW,$TREE)    

FROM($PATH)
    CONN(N,$BANDSTAND)
    CONN(E,$BUSSTOP)
    CONN(S,$GRASS)
    CONN(SW,$POND)
    CONN(W,$TREE)
    
FROM($BANDSTAND)
    CONN(S,$PATH)
    CONN(SW,$TREE)
    CONN(D,$CELLAR)

FROM($POND)
    CONN(N,$TREE)
    CONN(NE,$PATH)
    CONN(E,$GRASS)
    
FROM($TREE)
    CONN(U,$UPTREE)
    CONN(NE,$BANDSTAND)
    CONN(E,$PATH)
    CONN(SE,$GRASS)
    CONN(S,$POND)
        
FROM($UPTREE)
    CONN(D,$TREE)

FROM($CELLAR)
    CONN(U,$BANDSTAND)
    
$$EVENTS

// +----------------+
// | Events Section |
// +----------------+

// This game contains two non-player characters: a bird and a dog. The bird
// complicates the scenario as follows: it has the ticket at the start of the
// game (normally an unused location would be assigned to contain the birds
// objects, but in this game location $NOWHERE will be used instead, as we
// have only one non-player character which can have an object. This means 
// that the player must persuade the bird to drop the ticket, trying to GET it
// will result in an "I can't do that" message and the bird flying away. The 
// bird also flies between the Bandstand and the Tree Branch at regular
// intervals. The way to get the bird to drop the ticket will be to drop the
// sandwich at the same location. The dog is added to complicate the game a
// bit more. It will simply follow the player everywhere (being a very 
// obedient dog) and frighten the bird off. Now a dog would not be able to
// climb the tree so we must prevent the player from tempting the bird with
// the sandwich on the branch. To do so we will arrange for any object dropped
// while on the branch to fall to the ground. The player will be able to get
// rid of the dog by putting the lead on it and then tying the lead to the
// bench. In addition the player will be able to 'speak' to the dog which will
// provide another way of getting rid of the dog by asking it to SIT or STAY.

EVENT                                  // Look ACTION(GET,ALL) entry in the
    AT($IN_BAG)                        //   Actions Section for an explanation
    COPYFF($SAVE_CURLOC,$CURLOC)       //   of this entry...

EVENT
    ISDESC                             // Description in progress?
    AT($BANDSTAND)                     // Clear the screen only on bandstand
    CLS                                //   (this location has a picture)

EVENT
    ISDESC                             // Description in progress?
    SHOWLOC                            // Display the location
    NEWLINE
    LISTOBJ                            // List objects

EVENT
    AT($INTRO)                         // Initialize the position of the bird
    LET($BIRD_LOC,$UPTREE)             //   and the dog; note that they are
    LET($DOG_LOC,$BUSSTOP)             //   implemented as flags, not as 
    ANYKEY                             //   objects
    CLS
    PICON                              // Draw the picture always
    GOTO($BUSSTOP)                     // The game starts at the bus stop
    DESC                               // Describe the location

// Now follows set of entries which extend the usual description of the
// location to include info about eventual presence of a dog and a bird...

EVENT
    ISDESC                             // Description in progress?
    SAME($DOG_LOC,$CURLOC)             // A dog is here?
    MESSAGE(17)                        // Display this fact...
    EQ($DOG_STATE,$LEAD_ON_DOG)        // A lead is on the dog?
    MESSAGE(19)                        // A lead trails...
    
EVENT
    ISDESC                             // Description in progress?
    SAME($DOG_LOC,$CURLOC)             // A dog is here?
    EQ($DOG_STATE,$DOG_TIED)           // Dog is tied?
    MESSAGE(20)                        // Display this fact...

EVENT
    ISDESC                             // Description in progress?
    SAME($DOG_LOC,$CURLOC)             // A dog is here?
    NOTZERO($DOG_IS_SITTING)           // Dog is sitting?
    MESSAGE(24)                        // The dog is sitting quietly...

EVENT
    ISDESC                             // Description in progress?
    SAME($BIRD_LOC,$CURLOC)            // A bird is here?
    MESSAGE(9)                         // Display this fact...
    NOTCREATED($TICKET)                // Ticket not available anywhere?
    MESSAGE(10)                        // The bird has a ticket...

// The dog always follows the player except if it is sitting, or tied. Also,
// the dog will not follow the player up the tree...
    
EVENT
    NOTSAME($DOG_LOC,$CURLOC)          // A dog is not here?
    NOTEQ($DOG_STATE,$DOG_TIED)        // Dog is not tied?
    ZERO($DOG_IS_SITTING)              // Dog is not sitting?
    NOTAT($UPTREE)                     // Not at the top of the tree?
    COPYFF($CURLOC,$DOG_LOC)           // Move the dog here...
    MESSAGE(18)                        // The dog follows me...
    EQ($DOG_STATE,$LEAD_ON_DOG)        // A lead is on the dog?
    MESSAGE(19)                        // A lead trails...

// The bird is a big thief in this game...

EVENT
    COPYOF($TICKET,$OBJ_LOC)           // Find where is the ticket
    SAME($OBJ_LOC,$BIRD_LOC)           // At same location where bird is?
    ZERO($CNT1)                        // The bird is going to fly?
    DESTROY($TICKET)                   // The bird "gets" the ticket...
    SAME($BIRD_LOC,$CURLOC)            // The player is at the same location?
    MESSAGE(7)                         // Info: Bird snatches the ticket...

// The bird constantly flies between the bandstand and the top of the tree in
// regular intervals of three moves...

EVENT
    EQ($BIRD_LOC,$UPTREE)              // A bird is up the tree?
    ZERO($CNT1)                        // Is it the time for flying away?
    LET($BIRD_LOC,$BANDSTAND)          // Move the bird to the bandstand
    LET($CNT1,3)                       // Set the counter
    AT($UPTREE)                        // The player is at the same location?
    MESSAGE(14)                        // Info: Bird flies away...
        
EVENT
    EQ($BIRD_LOC,$BANDSTAND)           // A bird is on the bandstand?
    ZERO($CNT1)                        // Is it the time for flying away?
    LET($BIRD_LOC,$UPTREE)             // Move the bird to the tree
    LET($CNT1,3)                       // Set the counter
    AT($BANDSTAND)                     // The player is at the same location?
    MESSAGE(14)                        // Info: Bird flies away...
    
EVENT
    AT($BANDSTAND)                     // Bandstand?
    SAME($BIRD_LOC,$CURLOC)            // A bird is here?
    EQ($CNT1,3)                        // Bird just arrives?
    MESSAGE(11)                        // Bird settles on the ground...

EVENT
    AT($UPTREE)                        // Up the tree?
    EQ($BIRD_LOC,$UPTREE)              // A bird is here?
    EQ($CNT1,3)                        // Bird just arrives?
    MESSAGE(12)                        // Bird lands on the branch...

EVENT
    SAME($BIRD_LOC,$CURLOC)            // A bird is here?
    EQ($CNT1,3)                        // Bird just arrives?
    NOTCREATED($TICKET)                // Ticket not available anywhere?
    MESSAGE(10)                        // The bird has a ticket in its beak...

// The bird will always fly away immediately in presence of the dog...

EVENT
    SAME($BIRD_LOC,$DOG_LOC)           // Bird and dog are at the same loc?
    LET($BIRD_LOC,$UPTREE)             // Move the bird to the tree...
    LET($CNT1,3)                       // Set the counter
    AT($BANDSTAND)                     // The player is also there?
    MESSAGE(13)                        // Info: Bird sees dog...

// The bird will drop the ticket in presence of the sandwich...

EVENT
    COPYOF($SANDWICH,$OBJ_LOC)         // Find where is the sandwich
    SAME($OBJ_LOC,$BIRD_LOC)           // At the same location where bird is?
    NOTCREATED($TICKET)                // The ticket is in the beak?
    COPYFO($BIRD_LOC,$TICKET)          // Place the ticket there
    SAME($BIRD_LOC,$CURLOC)            // The player is also there?
    MESSAGE(6)                         // Bird drops the ticket...

// Finishing the game...

EVENT
    AT($BUSSTOP)                       // At the bus stop?
    CARRIED($TICKET)                   // Carried the ticket?
    SAME($DOG_LOC,$CURLOC)             // A dog is here?
    MESSAGE(4)                         // Well done...
    TURNS
    END

$$ACTIONS

// +-----------------+
// | Actions Section |
// +-----------------+

ACTION(D,_)
    AT($BANDSTAND)                     // Going to the cellar from the
    SET($DARK)                         //   bandstand need to set the dark...

ACTION(U,_)
    AT($CELLAR)                        // No dark out of the cellar...
    CLEAR($DARK)

ACTION(_,_)
    TRYMOVE                            // Try to perform standard movements
    DESC                               //   through the Connections Section

// This entry initializes some variables which may be useful later.

ACTION(_,_)
    CLEAR($WORKING_WITH_BAG)           // Assume "no work with bag" so far
    CLEAR($SPEECH_CHARACTER)           // Assume "no speech" so far...
    SET($SPEECH_VERB)                  // No speech verb ($NULL)...
    SET($SPEECH_NOUN)                  // No speech noun ($NULL)...
    WHATO($OBJ_NUM)                    // Find what is the referenced object
    CANCEL                             //   (this info may be useful later)

// Some very common entries...

ACTION(GET,I)
    INVEN
    
ACTION(I,_)
    INVEN
    
ACTION(R,_)
    DESC
    
ACTION(QUIT,_)
    QUIT 
    TURNS
    END
    
ACTION(SAVE,_)
    SAVE
  
ACTION(LOAD,_)
    LOAD

// RAMSAVE and RAMLOAD...

ACTION(RAMSAVE,_)
    RAMSAVE
    OK
  
ACTION(RAMLOAD,_)
    RAMLOAD
    DESC

// Looking in the bag...

ACTION(LOOK,IN)
    EXTWORD(BAG)                       // Phrase LOOK IN BAG?
    ABSENT($BAG)                       // No bag here?
    MESSAGE(26)                        // Tell this to the player...
    DONE
  ELSE
    EXTWORD(BAG)                       // Otherwise: LOOK IN BAG (bag is here)?
    MESSAGE(5)                         // In the bag is...
    LISTAT($IN_BAG)                    // List what is in it
    DONE

// We want to make LOOK equal to REDESCRIBE, but LOOK _object_ equal to
// EXAMINE _object_ ...

ACTION(LOOK,_)
    ISNULL($NOUN)                      // No valid noun present?
    DESC                               // Describe the location
  ELSE
    SETVERB(EXAMINE)                   // Otherwise, set verb to EXAMINE
  
ACTION(EXAMINE,SANDWICH)
    PRESENT($SANDWICH)                 // Sandwich is here?
    MESSAGE(1)                         // Cheese and pickle sandwich...
    DONE

ACTION(EXAMINE,APPLE)
    PRESENT($APPLE)                    // Apple is here?
    MESSAGE(0)                         // Crisp and green...
    DONE

ACTION(EXAMINE,TICKET)
    PRESENT($TICKET)                   // Ticket is here?
    MESSAGE(2)                         // Bus city company...
    DONE

ACTION(EXAMINE,BENCH)
    AT($PATH)                          // At the path (the bench is there)?
    MESSAGE(3)                         // Firmly screwed...
    DONE
    
ACTION(EXAMINE,BAG)
    PRESENT($BAG)                      // Bag is here?
    MESSAGE(31)                        // This gives the player a hint
    DONE
    
ACTION(EXAMINE,_)
    MESSAGE(30)                        // Nothing special...

ACTION(ON,TORCH)
    PRESENT($UNLIT_TORCH)              // Unlit torch is here?
    SWAP($LIT_TORCH,$UNLIT_TORCH)      // Turn it to the lit torch
    OK

ACTION(TORCH,ON)
    PRESENT($UNLIT_TORCH)              // Unlit torch is here?
    SWAP($LIT_TORCH,$UNLIT_TORCH)      // Turn it to the lit torch
    OK

ACTION(OFF,TORCH)
    PRESENT($LIT_TORCH)                // Lit torch is here?
    SWAP($LIT_TORCH,$UNLIT_TORCH)      // Turn it to the unlit torch
    OK

ACTION(TORCH,OFF)
    PRESENT($LIT_TORCH)                // Lit torch is here?
    SWAP($LIT_TORCH,$UNLIT_TORCH)      // Turn it to the unlit torch
    OK
    
ACTION(WAIT,_)
    MESSAGE(29)                        // Time passes...

ACTION(HELP,_)
    MESSAGE(36)                        // A clue...

// WEAR & REMOVE are implemented using automatic actions, although there is
// really only one object (an anorak) which can be worn...

ACTION(WEAR,_)
    AUTOW                              // Automatic wear...
    OK

ACTION(REMOVE,_)
    AUTOR                              // Automatic remove...
    OK

// Check for a phrases like GET _object_ FROM BAG & DROP _object_ IN BAG...

ACTION(GET,_)
    EXTWORD(FROM)                      // Third recognized word is FROM?
    EXTWORD(BAG)                       // Word BAG follows?
    SET($WORKING_WITH_BAG)             // Indicate working with the bag

ACTION(DROP,_)
    EXTWORD(IN)                        // Third recognized word is IN?
    EXTWORD(BAG)                       // Word BAG follows?
    SET($WORKING_WITH_BAG)             // Indicate working with the bag
    
ACTION(_,_)
    NOTZERO($WORKING_WITH_BAG)         // Working with the bag?
    ABSENT($BAG)                       // No bag here?
    MESSAGE(26)                        // There is no bag...
    DONE

// Note that if the phrase like GET _object_ FROM BAG is recognized, the
// scanning continues further, but with the $WORKING_WITH_BAG indicator set.

// Now follows some special getting actions...

ACTION(GET,TICKET)
    SAME($BIRD_LOC,$CURLOC)            // A bird (with a ticket) is here?
    NOTCREATED($TICKET)                // The ticket is not really available?
    CLEAR($CNT1)                       // Force the bird to fly away
    NOTDONE                            // Sorry, you can't...

ACTION(GET,SANDWICH)
    SAME($BIRD_LOC,$CURLOC)            // If both bird and sandwich are here,
    HERE($SANDWICH)                    //   force bird to fly away, but
    CLEAR($CNT1)                       //   continue further through GET _
    
ACTION(GET,TORCH)
    PRESENT($LIT_TORCH)                // A lit torch is here?
    LET($OBJ_NUM,$LIT_TORCH)           // Needed for GET TORCH FROM BAG
    ZERO($WORKING_WITH_BAG)            // Not getting from the bag?
    GET($LIT_TORCH)                    // Get it, else continue further...
    OK

// The Quill unfortunately has not a built-in support for implementing
// simple responses to phrases like GET ALL. However, they may be coded using
// a bit awkward method, which is adequate if the number of objects which
// may be taken is reasonably small. GET ALL FROM BAG is also supported here.

ACTION(GET,ALL)
    NOTZERO($WORKING_WITH_BAG)         // Phrase GET ALL FROM BAG?
    COPYFF($CURLOC,$SAVE_CURLOC)       // If it is, "enter" temporary into
    GOTO($IN_BAG)                      //   the bag...
  CONTINUE  
    COPYFF($NUMCAR,$SAVE_NUMCAR)       // Save temporary the number of
    HERE($LIT_TORCH)                   //   objects carried
    GET($LIT_TORCH)
  CONTINUE                             // Note that any of GET actions may   
    HERE($UNLIT_TORCH)                 //   fail if the maximum number of
    GET($UNLIT_TORCH)                  //   objects conveyable is reached;
  CONTINUE                             //   this may be very unpleasant if the
    HERE($BAG)                         //   player is temporary "in the bag";
    GET($BAG)                          //   so, in such case, the current
  CONTINUE                             //   location will eventually be
    HERE($SANDWICH)                    //   restored in the Events Section...
    GET($SANDWICH)
    SAME($BIRD_LOC,$CURLOC)            // Force the bird to fly away if it is
    CLEAR($CNT1)                       //   on the sandwich...
  CONTINUE
    HERE($APPLE)
    GET($APPLE)
  CONTINUE
    HERE($LEAD)
    GET($LEAD)
  CONTINUE
    HERE($APPLE)
    GET($APPLE)
  CONTINUE
    HERE($ANORAK)
    GET($ANORAK)
  CONTINUE
    AT($IN_BAG)                        // In the bag?
    COPYFF($SAVE_CURLOC,$CURLOC)       // Restore the original location...
  CONTINUE
    SAME($NUMCAR,$SAVE_NUMCAR)         // Anything really taken?
    MESSAGE(32)                        // Nothing to take...
    DONE
  ELSE
    OK

// Now code all other gettings...

ACTION(GET,_)
    ZERO($WORKING_WITH_BAG)            // Not getting from the bag?
    AUTOG                              // Perform a simple automatic get...
    OK
  ELSE
    ISNULL($OBJ_NUM)                   // Object not recognized?
    NOTDONE                            // You can't...
  ELSE
    WHEREO($OBJ_NUM,$OBJ_LOC)          // Where is the object?
    NOTEQ($OBJ_LOC,$IN_BAG)            // Not in the bag?
    MESSAGE(27)                        // It is not in the bag...
    DONE
  ELSE
    SAME($NUMCAR,$MAXCAR)              // Limit of objects reached?
    SYSMESS(27)                        // Can't carry any more...
    NEWLINE
    DONE
  ELSE  
    PUTO($OBJ_NUM,$CARRIED)            // Make it to be 'carried'
    OK

// Phrase PUT LEAD ON DOG should to be processed diferently than simple phrase
// PUT LEAD, which is equivalent to DROP LEAD...

ACTION(PUT,LEAD)
    EXTWORD(ON)                        // Phrase PUT LEAD ON DOG?
    EXTWORD(DOG)
    CARRIED($LEAD)                     // Lead is carried?
    SAME($DOG_LOC,$CURLOC)             // A dog is here?
    LET($DOG_STATE,$LEAD_ON_DOG)       // Well, put the lead on the dog...
    DESTROY($LEAD)                     // Lead is no more a separate object
    MESSAGE(21)                        // Dog lets me put the lead...
    DONE

// Forbid DROP BAG IN BAG...

ACTION(DROP,BAG)
    NOTZERO($WORKING_WITH_BAG)         // DROP BAG IN BAG?
    CARRIED($BAG)                      // Bag is carried?
    NOTDONE                            // I can't...

// The torch is "two objects in one"...

ACTION(DROP,TORCH)
    CARRIED($LIT_TORCH)                // A lit torch is carried?
    LET($OBJ_NUM,$LIT_TORCH)           // Needed eventually later...
    ZERO($WORKING_WITH_BAG)            // Not putting into the bag?
    NOTAT($UPTREE)                     // Not in the tree?
    DROP($LIT_TORCH)                   // Drop it, else continue further...
    OK

// In this game, we want to make more realistic dropping in the tree. So, any
// dropping in the tree will cause the object to fall to the ground instead of
// staying at the top of the tree...

// Coding DROP ALL (including "tree effect" and phrase PUT ALL IN BAG) is much
// simpler than coding of GET ALL...

ACTION(DROP,ALL)
    ZERO($NUMCAR)                      // Carrying nothing at all?
    MESSAGE(33)                        // My hands are empty...
    DONE
  ELSE
    NOTZERO($WORKING_WITH_BAG)         // Putting into the bag?
    COPYFF($CURLOC,$SAVE_CURLOC)       // Save the current location
    COPYOF($BAG,$OBJ_LOC)              // Save the location where the bag is    
    GOTO($IN_BAG)                      // Temporary "enter" into the bag...
    DROPALL                            // Drop everything there
    COPYFF($SAVE_CURLOC,$CURLOC)       // Restore the saved location
    COPYFO($OBJ_LOC,$BAG)              // Restore the location of the bag
    OK    
  ELSE
    AT($UPTREE)                        // In the tree?
    GOTO($TREE)                        // Temporary go to the bottom of tree
    DROPALL                            // Drop everything there
    GOTO($UPTREE)                      // Go back...
    MESSAGE(15)                        // It falls to the ground...    
    OK
  ELSE  
    DROPALL                            // Drop everything here
    OK

// Now code all other droppings...

ACTION(DROP,_)
    AT($UPTREE)                        // In the tree?
    ZERO($WORKING_WITH_BAG)            // Not putting into the bag?
    ISNOTNULL($OBJ_NUM)                // Object recognized?    
    WHEREO($OBJ_NUM,$OBJ_LOC)          // Find where is the object...
    EQ($OBJ_LOC,$CARRIED)              // Carried?
    MESSAGE(15)                        // It falls to the ground...
    PUTO($OBJ_NUM,$TREE)               // Put it at the foot of the tree
    DONE
  ELSE
    ZERO($WORKING_WITH_BAG)            // Not putting into the bag?
    AUTOD                              // Perform a simple automatic drop...
    OK
  ELSE
    ISNULL($OBJ_NUM)                   // Object not recognized?
    NOTDONE                            // You can't...
  ELSE
    WHEREO($OBJ_NUM,$OBJ_LOC)          // Where is the object?
    EQ($OBJ_LOC,$WORN)                 // Worn?
    MESSAGE(28)                        // Remove it first...
    DONE
  ELSE  
    EQ($OBJ_LOC,$CARRIED)              // Carried?
    PUTO($OBJ_NUM,$IN_BAG)             // Well, put it in the bag...
    OK                                 
  ELSE                                 // Else, perform AUTOD, which will fail, 
    AUTOD                              //   producing an appropriate message
    
ACTION(TIE,DOG)
    SETNOUN(LEAD)                      // TIE LEAD and TIE DOG should cause
    CANCEL                             //   the same response...

ACTION(TIE,LEAD)
    SAME($DOG_LOC,$CURLOC)             // A dog is here?
    NOTEQ($DOG_STATE,$LEAD_ON_DOG)     // A lead is not on the dog?
    MESSAGE(34)                        // You should to put the lead...
    DONE
  ELSE
    SAME($DOG_LOC,$CURLOC)             // A dog is here?
    EQ($DOG_STATE,$LEAD_ON_DOG)        // A lead is on the dog?
    EXTWORD(_)                         // Only verb and noun?
    MESSAGE(35)                        // Be more concrete...
    DONE
  ELSE
    SAME($DOG_LOC,$CURLOC)             // A dog is here?
    EQ($DOG_STATE,$LEAD_ON_DOG)        // A lead is on the dog?
    AT($PATH)                          // At the path (the bench is there)?    
    EXTWORD(TO)                        // Only TIE LEAD TO BENCH is concrete
    EXTWORD(BENCH)                     //   enough to be executed...
    LET($DOG_STATE,$DOG_TIED)          // Well, tie the dog
    MESSAGE(22)                        // I've tied the lead...
    DONE
    
ACTION(UNTIE,DOG)
    SETNOUN(LEAD)                      // UNTIE LEAD and UNTIE DOG should
    CANCEL                             //   cause the same response...

ACTION(UNTIE,LEAD)
    AT($PATH)                          // At the path (the bench is there)?
    EQ($DOG_STATE,$DOG_TIED)           // The dog is tied?
    CLEAR($DOG_STATE)                  // No more...
    MESSAGE(25)                        // I've untied the dog...
    CREATE($LEAD)                      // Create the lead here
    GET($LEAD)                         // Get it
    DONE

// Here will be coded an inteligent parsing of speech to the characters (the
// bird and the dog in this game). If the game should understand only fixed
// phrases like SAY SIT TO DOG, this could be coded simply as
//
// ACTION(SAY,SIT)
//     EXTWORD(TO)
//     EXTWORD(DOG)
//     ...
//
// But, such approach is not flexible. Particularly, with such coding, the
// sentences like SAY TO DOG SIT or ASK DOG TO SIT will not be understand. If
// we want to allow understanding of a lot of phrases like SAY COME TO DOG, 
// SAY COME HERE TO DOG, SAY TO DOG COME HERE, ASK COME HERE TO DOG etc. we 
// would need a lot of entries, which is too awkward. Here will be shown a 
// much better approach. The following subroutine allows recognizing of 
// sentences of following types:
//
// SAY TO _character_ _verb_
// SAY TO _character_ _verb_ _noun_
// SAY _verb_ TO _character_
// SAY _verb_ _noun_ TO _character_
// ASK _character_ TO _verb_
// ASK _character_ TO _verb_ _noun_
//
// Information about the _character_, the _verb_ and the _noun_ will be
// extracted, regardless of which form is used. Such subroutine should be at
// the very end of the Actions Section, after all other responses are coded.
// Note. however, that the entry which initializes speech variables 
// $SPEECH_CHARACTER, $SPEECH_VERB and $SPEECH_NOUN is coded at the very
// begining of the Actions Section!

ACTION(SAY,_)
    SET($SPEECH_CHARACTER)             // Signal "speech in progress"...

ACTION(SAY,TO)                         // Phrase SAY TO _char_ _verb_ [_noun_]
    GETWORD($SPEECH_CHARACTER)         // Simply pick up three word numbers
    GETWORD($SPEECH_VERB)              //   which determines the character,
    GETWORD($SPEECH_NOUN)              //   the verb and the (optional) noun

ACTION(SAY,_)                          // Phrase SAY _verb_ TO _char_
    EXTWORD(TO)                        // Third word is TO?
    GETWORD($SPEECH_CHARACTER)         // Well, the next word is the character
    COPYFF($NOUN,$SPEECH_VERB)         //   and the second word is the verb...

ACTION(SAY,_)                          // Phrase SAY _verb_ _noun_ TO _char_
    GETWORD($THIRD_WORD)               // Get the third word
    EXTWORD(TO)                        // Fourth word is TO?
    GETWORD($SPEECH_CHARACTER)         // Well, the next word is the character
    COPYFF($NOUN,$SPEECH_VERB)         //   and second & third words are the
    COPYFF($THIRD_WORD,$SPEECH_NOUN)   //   verb and the noun respectively...

ACTION(ASK,_)                          // Phrase ASK _char_ TO _verb_ [_noun_]
    COPYFF($NOUN,$SPEECH_CHARACTER)    // The noun is the character...
    EXTWORD(TO)                        // Third word is TO?
    GETWORD($SPEECH_VERB)              // Well, the next word is the verb, and
    GETWORD($SPEECH_NOUN)              //   an eventual word after is the noun

ACTION(_,_)
    NOTZERO($SPEECH_CHARACTER)         // Speech in progress?
    COPYFF($SPEECH_VERB,$VERB)         // Copy extracted _verb_ and _noun_
    COPYFF($SPEECH_NOUN,$NOUN)         //   into W1 and W2 to make them a real
    CANCEL                             //   verb and a real noun...

// Now, the subroutine for parsing of the speech is done. Note that now the 
// original structure of the input phrase is totally changed (that's why this
// subroutine should be at the end of the Actions Section). For example, the
// input phrases like SAY COME HERE TO DOG or SAY TO DOG COME HERE are turned
// into a simple phrase COME HERE, but the flag $SPEECH_CHARACTER contains the
// information about the object of the speech (or $NULL if the object is not
// recognized). It will contain zero if speech is not in the progress (i.e. if
// the verb SAY is not detected at all in the original input phrase).

// Speech to the bird: it will ignore everything...

ACTION(_,_)
    EQWORD($SPEECH_CHARACTER,BIRD)     // Speech to the bird?
    SAME($BIRD_LOC,$CURLOC)            // Bird is here?
    MESSAGE(8)                         // Bird ignores me...    
    DONE

// Speech to the dog: it understands simple commands like SIT, COME, COME HERE
// etc.

ACTION(_,_)
    EQWORD($SPEECH_CHARACTER,DOG)      // Speech to the dog?
    SAME($DOG_LOC,$CURLOC)             // Dog is here?
    ISNULL($VERB)                      // Verb not recognized?
    MESSAGE(16)                        // Dog's eyes stare at me...
    DONE    
    
ACTION(SIT,_)
    EQWORD($SPEECH_CHARACTER,DOG)      // Speech to the dog?
    SAME($DOG_LOC,$CURLOC)             // Dog is here?
    ZERO($DOG_IS_SITTING)              // Not sitting?
    SET($DOG_IS_SITTING)               // Well, make it sitting...
    MESSAGE(24)                        // The dog is sitting quietly...
    DONE

ACTION(COME,_)
    EQWORD($SPEECH_CHARACTER,DOG)      // Speech to the dog?
    SAME($DOG_LOC,$CURLOC)             // Dog is here?
    NOTZERO($DOG_IS_SITTING)           // Sitting?
    CLEAR($DOG_IS_SITTING)             // No more...
    MESSAGE(18)                        // The dog follows me
    DONE

ACTION(_,HERE)
    EQWORD($SPEECH_CHARACTER,DOG)      // Speech to the dog?
    SAME($DOG_LOC,$CURLOC)             // Dog is here?
    NOTZERO($DOG_IS_SITTING)           // Sitting?
    CLEAR($DOG_IS_SITTING)             // No more...
    MESSAGE(18)                        // The dog follows me
    DONE
    
ACTION(_,_)                            // Anything else...
    EQWORD($SPEECH_CHARACTER,DOG)      // Speech to the dog?
    SAME($DOG_LOC,$CURLOC)             // Dog is here?
    MESSAGE(16)                        // Dog's eyes stare at me...
    DONE    
  ELSE
    NOTZERO($SPEECH_CHARACTER)         // Speech in progress?
    MESSAGE(23)                        // Who should I say it to!?

$$PICTURES

// +------------------+
// | Pictures Section |
// +------------------+

// This game contains one picture (at the bandstand), more as a surprise. 
// It is drawn as a monochrome bitmap (BMP) using Windows Paint, converted to
// a raw binary file using Image Studio by Matthew Johnson, and finally 
// converted to a hex array using an another tool called TTBIN2HEX from the
// TIGCC Tools Suite package by Thomas Nussbaumer.

BITMAP($BANDSTAND,144,74,$CENTER,0,75)
    0x0892,0x4924,0x9249,0x2492,0x4924,0x9249,0x2492,0x4924,0x9248,0x0124,
    0x9249,0x2492,0x4924,0x9249,0x2492,0x4924,0x9249,0x2490,0x0249,0x2492,
    0x4924,0x9249,0x2492,0x4924,0x9249,0x2492,0x4920,0x05FF,0xFFFF,0xFFFF,
    0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFC8,0x0955,0x5555,0x5555,0x5555,
    0x5545,0x5555,0x5555,0x5555,0x5550,0x03AA,0xAAAA,0xAAAA,0xAAAA,0xAA32,
    0xAAAA,0xAAAA,0xAAAA,0xAAE0,0x0555,0x5555,0x5555,0x5555,0x5048,0x5555,
    0x5555,0x5555,0x5548,0x09AA,0xAAAA,0xAAAA,0xAAAA,0x8084,0x0AAA,0xAAAA,
    0xAAAA,0xAAD0,0x0355,0x5555,0x5555,0x5554,0x0303,0x0155,0x5555,0x5555,
    0x5560,0x05AA,0xAAAA,0xAAAA,0xAAA0,0x0400,0x802A,0xAAAA,0xAAAA,0xAAC8,
    0x0955,0x5555,0x5555,0x5500,0x0800,0x4015,0x5555,0x5555,0x5550,0x03AA,
    0xAAAA,0xAAAA,0xA800,0x1000,0x2000,0xAAAA,0xAAAA,0xAAE0,0x0555,0x5555,
    0x5555,0x5000,0x2000,0x1000,0x5555,0x5555,0x5548,0x09AA,0xAAAA,0xAAAA,
    0x0000,0x4000,0x0800,0x0AAA,0xAAAA,0xAAD0,0x0355,0x5555,0x5550,0x0000,
    0x8000,0x0400,0x0055,0x5555,0x5560,0x05AA,0xAAAA,0xAAA0,0x0003,0x0000,
    0x0300,0x002A,0xAAAA,0xAAC8,0x0955,0x5555,0x5400,0x0004,0x0000,0x0080,
    0x0005,0x5555,0x5550,0x03AA,0xAAAA,0xA800,0x0008,0x0000,0x0040,0x0000,
    0xAAAA,0xAAE0,0x0555,0x5555,0x4000,0x0010,0x0000,0x0020,0x0000,0x1555,
    0x5548,0x09AA,0xAAA8,0x02AA,0xAA85,0x5555,0x550A,0xAAAA,0x82AA,0xAAD0,
    0x0355,0x5551,0x4000,0x0000,0x0000,0x0000,0x0000,0x1155,0x5560,0x05AA,
    0xAA82,0xA0A1,0x4285,0x0A14,0x2850,0xA140,0x2A2A,0xAAC8,0x0955,0x5555,
    0x5152,0xA54A,0x952A,0x54A9,0x52A0,0x5555,0x5550,0x03AA,0xAAAA,0xA8A1,
    0x4285,0x0A14,0x2850,0xA140,0xAAAA,0xAAE0,0x0555,0x5555,0x5400,0x0000,
    0x0000,0x0000,0x0001,0x5555,0x5548,0x09AA,0xAAAA,0xAAAA,0x8AAA,0xAA8A,
    0xAAAA,0x8AAA,0xAAAA,0xAAD0,0x0355,0x5555,0x5555,0x0555,0x5505,0x5555,
    0x0555,0x5555,0x5560,0x05AA,0xAAAA,0xAAAA,0x8AAA,0xAA8A,0xAAAA,0x8AAA,
    0xAAAA,0xAAC8,0x0955,0x5555,0x5555,0x0555,0x5505,0x5555,0x0555,0x5555,
    0x5550,0x03AA,0xAAAA,0xAAAA,0x8AAA,0xAA8A,0xAAAA,0x8AAA,0xAAAA,0xAAE0,
    0x0555,0x5555,0x5555,0x0555,0x5505,0x5555,0x0555,0x5555,0x5548,0x09AA,
    0xAAAA,0xAAAA,0x8AAA,0xAA8A,0xAAAA,0x8AAA,0xAAAA,0xAAD0,0x0355,0x5555,
    0x5555,0x0555,0x5505,0x5555,0x0555,0x5555,0x5560,0x05AA,0xAAAA,0xAAAA,
    0x8AAA,0xAA8A,0xAAAA,0x8AAA,0xAAAA,0xAAC8,0x0955,0x5555,0x5555,0x0555,
    0x5505,0x5555,0x0555,0x5555,0x5550,0x03AA,0xAAAA,0xAAAA,0x8AAA,0xAA8A,
    0xAAAA,0x8AAA,0xAAAA,0xAAE0,0x0555,0x5555,0x5555,0x0555,0x5505,0x5555,
    0x0555,0x5555,0x5548,0x09AA,0xAAAA,0xAAAA,0x8AAA,0xAA8A,0xAAAA,0x8AAA,
    0xAAAA,0xAAD0,0x0355,0x5555,0x5555,0x0555,0x5505,0x5555,0x0555,0x5555,
    0x5560,0x05AA,0xAAAA,0xAAAA,0x8AAA,0xAA8A,0xAAAA,0x8AAA,0xAAAA,0xAAC8,
    0x0955,0x5555,0x5FFF,0x8FFF,0x5505,0x57FF,0x8FFF,0xD555,0x5550,0x03AA,
    0xAAAA,0xB39C,0x8F3B,0xFF8F,0xFCE7,0x09CE,0xAAAA,0xAAE0,0x0555,0x5555,
    0x5AD6,0x8DEF,0x7B06,0xB5AD,0x0B5A,0xD555,0x5548,0x09BB,0xBBBB,0xBFFF,
    0xFFDE,0xF78D,0xEF7F,0xFEF7,0xBBBB,0xBBD0,0x0355,0x5555,0x5F7B,0xDEF7,
    0xBD8F,0xFFFF,0xFF7B,0xD555,0x5560,0x05FF,0xFFFF,0xFBDE,0xF7FF,0xFF07,
    0xBDEF,0xBB5A,0xFFFF,0xFFC8,0x0955,0x5555,0x539C,0xF73B,0xCE03,0x9CE7,
    0xB9CE,0xD555,0x5550,0x03BB,0xBBBB,0xBAD6,0xF5EF,0x7B06,0xB5AF,0xAB5A,
    0xBBBB,0xBBE0,0x0555,0x5555,0x5FFF,0xFFDF,0xFFEF,0xFFFF,0xFFFF,0xD555,
    0x5548,0x09BB,0xBBBB,0xB9CE,0x739C,0xFFFF,0xFE73,0x9CE7,0xBBBB,0xBBD0,
    0x0355,0x5555,0x5FFF,0xFFFF,0x8000,0x0FFF,0xFFFF,0xD555,0x5560,0x05BB,
    0xBBBB,0xB084,0x2108,0xFFFF,0xFC21,0x0842,0xBBBB,0xBBC8,0x0955,0x5555,
    0x5FFF,0xFFFF,0x8000,0x0FFF,0xFFFF,0xD555,0x5550,0x03FF,0xFFFF,0xF210,
    0x8442,0xFFFF,0xF908,0x4210,0xFFFF,0xFFE0,0x0522,0x2222,0x3FFF,0xFFFF,
    0x8000,0x0FFF,0xFFFF,0xA222,0x2248,0x0988,0x8888,0x9084,0x2108,0xFFFF,
    0xFC21,0x0842,0x8888,0x88D0,0x0322,0x2232,0x3FFF,0xFFFF,0x8000,0x0FFF,
    0xFFFF,0xA222,0x2260,0x0589,0x88DC,0x9210,0x8442,0xFFFF,0xF908,0x4210,
    0x89A8,0x88C8,0x0923,0x327E,0x3FFF,0xFFFF,0x8000,0x0FFF,0xFFFF,0xA3AA,
    0x2250,0x0389,0x98BE,0x9084,0x2108,0xFFFF,0xFC21,0x0842,0x8DB8,0x88E0,
    0x052B,0xBA26,0x3FFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xA6FA,0x2248,0x09AC,
    0xD889,0x8888,0x8888,0x8888,0x8888,0x8888,0x8FEC,0x88D0,0x0336,0xFA22,
    0x2222,0x6622,0x2222,0x2222,0x2222,0x26AE,0x2260,0x059D,0xBC88,0x8888,
    0xDC88,0x8888,0x8888,0x8888,0x8D8C,0x88C8,0x0936,0xB622,0x2223,0x3622,
    0x2222,0x2222,0x2222,0x2722,0x2250,0x039A,0x9A88,0x8889,0xEE88,0x8888,
    0x8888,0x8888,0x8C88,0x88E0,0x052A,0x2222,0x2222,0xBF22,0x2222,0x2222,
    0x2222,0x2222,0x2248,0x0988,0x8888,0x8888,0x9C88,0x8888,0x8888,0x8888,
    0x8888,0x88D0,0x0322,0x2222,0x2222,0x2622,0x2222,0x2222,0x2222,0x2222,
    0x2260,0x0588,0x8888,0x8888,0x8888,0x8888,0x8888,0x8888,0x8888,0x88C8,
    0x09FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFD0,0x0249,
    0x2492,0x4924,0x9249,0x2492,0x4924,0x9249,0x2492,0x4920,0x0492,0x4924,
    0x9249,0x2492,0x4924,0x9249,0x2492,0x4924,0x9248,0x0924,0x9249,0x2492,
    0x4924,0x9249,0x2492,0x4924,0x9249,0x2490,
END_BITMAP

$$EXTERN

// +------------------+
// | External Section |
// +------------------+

// No external modules...

$$END
