// The demonstration game for The Quill Adventure Writer by Zeljko Juric.
// Originally written as a tutorial game for the Graphic Adventure Creator for
// the ZX Spectrum by Sean Ellis, Incentive Software.
// Significantly improved and ported to The Quill (TI version) by Zeljko Juric.

// This game is a coding example, which illustrates some more advanced coding
// tricks, like usage of the packed bitmap pictures, implementation of 
// pronouns (IT), movements with side effects, non-eternal light sources,
// making some objects heavier than other ones, coding of automatic actions
// (for examining objects in this example) using WHATO and WHEREO commands,
// implementation of OOPS or UNDO commands, etc.

$$TITLE("King's Ransom")

// +-----------------+
// | Aliases Section |
// +-----------------+

// Locations aliases

DEFINE(INTRO,0)
DEFINE(BRIDGE,1)
DEFINE(CAVE,2)
DEFINE(TUNNEL,3)
DEFINE(LAKE,4)
DEFINE(MOAT,5)
DEFINE(CASTLE,6)

// Objects aliases

DEFINE(LIT_LAMP,0)
DEFINE(LAMP,1)
DEFINE(RAT,2)
DEFINE(KEY,3)
DEFINE(GOLD,4)

// Flags aliases

DEFINE(KEY_TAKEN,11)                   // Nonzero after first taking the key
DEFINE(DOOR_OPENED,12)                 // Nonzero if the door is opened
DEFINE(LAMP_COUNTER,13)                // Counts how long the lamp is lit
DEFINE(LAMP_HAS_GONE,14)               // Nonzero if the lamp has gone
DEFINE(WHAT_IS_PRONOUN,15)             // Keeps what the pronoun IT refers to
DEFINE(OBJ_NUM,16)                     // Number of the referenced object
DEFINE(OBJ_LOC,17)                     // Location of the referenced object

$$VOCABULARY(4)

// +--------------------+
// | Vocabulary Section |
// +--------------------+

// Movement words

WORD(1,N)
WORD(1,NORTH)
WORD(2,S)
WORD(2,SOUTH)
WORD(3,E)
WORD(3,EAST)
WORD(4,W)
WORD(4,WEST)
WORD(5,NE)
WORD(6,NW)
WORD(7,SE)
WORD(8,SW)
WORD(9,U)
WORD(9,UP)
WORD(9,CLIMB)
WORD(9,ASCEND)
WORD(10,D)
WORD(10,DOWN)
WORD(10,DESCEND)

// Nouns

WORD(30,GOLD)
WORD(30,BAR)
WORD(31,DOOR)
WORD(32,KEY)
WORD(33,LAKE)
WORD(33,WATER)
WORD(34,LAMP)
WORD(34,TORCH)
WORD(35,RAT)
WORD(36,SERPENT)
WORD(36,SNAKE)
WORD(37,TREASURE)
WORD(38,TREE)

// Verbs and verb-like words

WORD(100,GET)
WORD(100,TAKE)
WORD(101,DROP)
WORD(102,REMOVE)
WORD(103,WEAR)
WORD(104,I)
WORD(104,INVENTORY)
WORD(104,LIST)
WORD(105,R)
WORD(105,REDESCRIBE)
WORD(106,QUIT)
WORD(106,STOP)
WORD(107,SAVE)
WORD(108,LOAD)
WORD(108,RESTORE)
WORD(109,BREAK)
WORD(109,BASH)
WORD(109,HIT)
WORD(109,KICK)
WORD(109,SMASH)
WORD(110,EAT)
WORD(110,MUNCH)
WORD(111,EXAMINE)
WORD(111,SEARCH)
WORD(112,EXTINGUISH)
WORD(112,OFF)
WORD(112,UNLIGHT)
WORD(113,LIGHT)
WORD(113,ON)
WORD(114,HELP)
WORD(115,WAIT)
WORD(115,SKANK)
WORD(116,SCORE)
WORD(117,SWIM)
WORD(118,OPEN)
WORD(119,UNLOCK)
WORD(120,PICTURES)
WORD(121,TEXT)
WORD(121,WORDS)
WORD(122,ONCE)
WORD(122,NORMAL)
WORD(123,OOPS)
WORD(123,UNDO)
WORD(124,LOOK)
WORD(124,L)

// Pronouns

WORD(150,IT)

$$LOCATIONS

// +-------------------+
// | Locations Section |
// +-------------------+

LOC($INTRO,"THE KING HAS BEEN KIDNAPPED BY A BAND OF MARAUDING PICTS, WHO "
    "ARE KEEPING HIM INCARCERATED IN THE DUNGEON OF A CASTLE TO THE NORTH..."
    "\n\nYOUR TASK IS A SIMPLE ONE... RETRIEVE THE GOLD THAT WILL PAY THE "
    "KING'S RANSOM!")
LOC($BRIDGE,"You find yourself on the bank of a turbulent stream, babbling "
    "along the base of the mountain itself. It is crossed by a stone bridge "
    "leading East to a dark cave entrance.")
LOC($CAVE,"Inside the mountain it is very gloomy. There is a patch of "
    "sunlight to the West, and dim tunnels wind away to the South and to the "
    "East.")
LOC($TUNNEL,"You are inside the mountain, in a tunnel leading East-West. "
    "There is another tunnel South, across a great crevasse, and a small "
    "snake is sleeping in its favourite cranny.")
LOC($LAKE,"You have emerged onto a promontory from the tunnel in the rock "
    "face to your West. To the East is a huge lake, bordered by the "
    "mountains, and a solitary tree graces the waters edge.")
LOC($MOAT,"A moat to the East surrounds a fortress of titanic proportions. "
    "The tunnel from which you came is North, and a drawbridge crosses the "
    "moat from West to East.")
LOC($CASTLE,"Inside the castle it is a little grim, especially for anyone "
    "unfortunate enough to be incarcerated here in the dungeon. The massive "
    "door to the West ensures few escape.")

$$MESSAGES

// +------------------+
// | Messages Section |
// +------------------+

// It is good practice to define detailed object description messages (i.e.
// messages which would be displayed when the user tries to examine the 
// object)to have same numbers as object numbers. This make coding of 
// EXAMINE _object_ easier...

MSG($LIT_LAMP,"It is an old lamp, shining brightly.")
MSG($LAMP,"It is old, but still looks servicable.")
MSG($RAT,"It must be freshly dead, as it is still warm.")
MSG($KEY,"It is a large, rusty key.")
MSG($GOLD,"It must be worth a fortune, judging by the size of it.")

// Other messages...

MSG(5,"You can't walk through doors, you know!")
MSG(6,"\nIts slumber disturbed, the snake rears its foul head and bites you! "
    "The poison kills you quickly and painlessly.")
MSG(7,"\nWell done! The gold you have brought is enough to pay a king's "
    "ransom!")
MSG(8,"With a grating sound, the key turns in the lock, and the door swings "
    "open.")
MSG(9,"\nThe snake awakes, and having spied the rat, devours it. It then "
    "returns to its corner to sleep.")
MSG(10,"The serpent wakes, and shows its disgust by biting your hand as you "
    "stoop to pick it up! The venom is swift and painless in its fatal "
    "effect.")
MSG(11,"It lights up, giving a surprisingly strong light.")
MSG(12,"It flickers and goes out.")
MSG(13,"It tastes even better than it looks! Yum yum!")
MSG(14,"You find nothing of interest.")
MSG(15,"I'm afraid that I don't know what that is.")
MSG(16,"On examining the tree, you dislodge something from a hole in a "
    "branch. It falls to the ground with a metallic clang.")
MSG(17,"Walls of granite rush past as you plunge into the pit, moments later "
    "you meet your doom on the jagged rocks below!")
MSG(18,"You feel the icy waters and change your mind!")
MSG(19,"\nYou can hear scuffling footsteps nearby...")
MSG(20,"\nA giant spider with glowing red eyes leaps from the shadows and "
    "neatly severs your head with powerful jaws before devouring you!")
MSG(21,"Time passes...")
MSG(22,"It's locked.")
MSG(23,"It is a heavy oak door, looks very strong.")
MSG(24,"What with!?")
MSG(25,"Your feeble efforts have no effect whatsoever!")
MSG(26,"It's already open.")
MSG(27,"Sorry, but I can't give away any clues!")
MSG(28,"Nothing happens.")
MSG(29,"There is no any water here.")
MSG(30,"It is very dangerous to move in the darkness. You fell and broke "
    "your neck...")
MSG(31,"You were not careful, so you broke the lamp.")    
MSG(32,"\nThe lamp is growing dim.")
MSG(33,"\nThe lamp has run out.")

$$SYSTEM_MESSAGES

// +-------------------------+
// | System Messages Section |
// +-------------------------+

MSG(0,"It's dark, you cannot see.")
MSG(1,"You can also see:")
MSG(2,"What now?")
MSG(6,"I beg your pardon?")
MSG(7,"I'm sorry, but you can't go in that direction.")
MSG(8,"I'm sorry, but you are unable to do that.")
MSG(9,"You are carrying:")
MSG(11,"Nothing.")
MSG(12,"Are you sure (Y/N)?")
MSG(13,"Do you want another game?")
MSG(14,"\nPRESS ANY KEY TO EXIT...")
MSG(15,"Okay.")
MSG(16,"\nPRESS A KEY TO START...")
MSG(17,"You have taken ")
MSG(18," turn")
MSG(19,"s")
MSG(20,".")
MSG(21,"Your score is ")
MSG(22," out of 100.")
MSG(25,"You already have one of those.")
MSG(26,"You can't see that anywhere.")
MSG(27,"You are carrying too much to pick that up.")
MSG(28,"You don't have one of those.")
MSG(30,"Y")
MSG(31,"N")

$$OBJECTS(4)                           // The player can carry 4 objects

// +-----------------+
// | Objects Section |
// +-----------------+

// Principally, in according to above settings, the player is able to carry 4
// objects at the same time, but we will code later the gold bar to be a 
// "heavy" object which is as heavy as three other objects, so the player will
// not be able to carry the gold bar, the key and the lamp at the same time...

OBJ($LIT_LAMP,"A lit lamp.",_,$NOWHERE)
OBJ($LAMP,"An old oil lamp.",LAMP,1)
OBJ($RAT,"A dead rat.",RAT,5)
OBJ($KEY,"A key.",KEY,$NOWHERE)
OBJ($GOLD,"A gold bar.",BAR,6)

$$CONNECTIONS

// +---------------------+
// | Connections Section |
// +---------------------+

FROM($BRIDGE)
    CONN(E,$CAVE)

FROM($CAVE)
    CONN(E,$TUNNEL)
    CONN(S,$MOAT)
    CONN(W,$BRIDGE)

FROM($TUNNEL)
    CONN(W,$CAVE)
    CONN(E,$LAKE)

FROM($LAKE)
    CONN(W,$TUNNEL)

FROM($MOAT)
    CONN(N,$CAVE)
    CONN(E,$CASTLE)

FROM($CASTLE)
    CONN(W,$MOAT)

$$EVENTS

// +----------------+
// | Events Section |
// +----------------+

EVENT
    ISDESC                             // Description in progress?
    CLS                                // Clear screen
    SHOWLOC                            // Display the location
    NEWLINE
    LISTOBJ                            // List objects

EVENT
    AT($INTRO)                         // Intro screen?
    ANYKEY                             // Wait for a keypress...
    SET($WHAT_IS_PRONOUN)              // So far, pronoun is meaningless
    PROMPT(2)                          // Always "What now?" prompt
    GOTO($BRIDGE)                      // The game starts at the bridge
    DESC                               // Describe the new location

// The intention here is that if the player spent too many time in caves,
// then he/she will be attacked by the giant spider...

EVENT
    NOTZERO($DARK)                     // Somewhere in caves?
    ZERO($DARKCNT)                     // The counter not set yet?
    LET($DARKCNT,4)                    // Set the counter to 4 (max. 4 moves)

EVENT
    ZERO($DARK)                        // Not in caves?
    CLEAR($DARKCNT)                    // Clear the counter

EVENT
    EQ($DARKCNT,2)                     // The counter equals to 2?
    MESSAGE(19)                        // You hear footsteps...

EVENT
    EQ($DARKCNT,1)                     // The counter equals to 1?
    MESSAGE(20)                        // The spider attacks you...
    SCORE                              // Bad luck!
    TURNS
    END
    
// Now, the intention is to make the lit lamp non-eternal: its life is at 
// most 12 turns. After this, the player will not be able to turn the lamp on
// again. Note that the lit lamp must be turned into the unlit lamp after 12 
// turns even if it is not at the same location where the player is...
    
EVENT
    CREATED($LIT_LAMP)                 // Does the lit lamp exists anywhere?
    MINUS($LAMP_COUNTER,1)             // If exists, decrement the counter
    ZERO($LAMP_COUNTER)                // The counter reached zero?
    SWAP($LAMP,$LIT_LAMP)              // If yes, turn off the lamp
    SET($LAMP_HAS_GONE)                // Signal that the lamp has gone
    PRESENT($LAMP)                     // Is the lit lamp available?
    MESSAGE(33)                        // Inform the player (lamp run out...)
    
EVENT
    EQ($LAMP_COUNTER,3)                // The counter equal to 3?
    PRESENT($LIT_LAMP)                 // Is the lit lamp just available?
    MESSAGE(32)                        // Inform the player (growing dim...)

// The next event which should to be coded is the deadly snake. Note that the
// order of the following two entries is very important!

EVENT
    AT($TUNNEL)                        // In the tunnel?
    PRESENT($LIT_LAMP)                 // Light source present?
    CARRIED($RAT)                      // Carrying the rat?
    PLUS($SCORE,20)                    // Some points to the player...
    MESSAGE(9)                         // The snake devours the rat...
    DESTROY($RAT)                      // Now, the rat is digested...

EVENT
    AT($TUNNEL)                        // In the tunnel?
    PRESENT($LIT_LAMP)                 // Light source present?
    CREATED($RAT)                      // The rat is not eaten by the snake?
    MESSAGE(6)                         // The snake bits you...
    SCORE                              // Bad luck!
    TURNS
    END

// Final event is the end of the game...

EVENT
    AT($BRIDGE)                        // At the bridge?
    CARRIED($GOLD)                     // Carrying the gold?
    PLUS($SCORE,20)                    // Final score    
    MESSAGE(7)                         // Well done...
    SCORE
    TURNS
    END
        
$$ACTIONS

// +-----------------+
// | Actions Section |
// +-----------------+

// "OOPS" or "UNDO" entries, if implemented, should always be the very first
// entries in the Actions Section.

ACTION(OOPS,_)
    RAMLOAD                            // Restore the saved state
    DESC

ACTION(_,_)
    RAMSAVE                            // Save the current state
    CANCEL

// The intention is to make moving in the dark (i.e. inside the caves) deadly
// if there is no lit lamp present.

ACTION(_,_)
    LT($VERB,13)                       // Movement word?
    NOTZERO($DARK)                     // In the caves?
    ABSENT($LIT_LAMP)                  // No lit lamp here?
    MESSAGE(30)                        // You fell and broke your neck...
    SCORE                              // Bad luck!
    TURNS
    END

// Other movements with side effects...

ACTION(N,_)
    AT($MOAT)                          // Moat?
    SET($DARK)                         // Going into the darkness...

ACTION(S,_)
    AT($TUNNEL)                        // Tunnel?
    MESSAGE(17)                        // Walls of granite rush past...
    SCORE                              // Bad luck!
    TURNS
    END
  ELSE
    AT($CAVE)                          // Cave?
    CLEAR($DARK)                       // Going to the daylight...

ACTION(E,_)
    AT($MOAT)                          // Moat?
    ZERO($DOOR_OPENED)                 // Door not opened?
    MESSAGE(5)                         // Can't walk through doors...
    DONE
  ELSE
    AT($LAKE)                          // Lake?
    MESSAGE(18)                        // Water is icy...
    DONE
  ELSE  
    AT($BRIDGE)                        // Bridge?
    SET($DARK)                         // Going into the darkness...
  ELSE
    AT($TUNNEL)                        // Tunnel?
    CLEAR($DARK)                       // Going to the daylight...

ACTION(W,_)
    AT($CAVE)                          // Cave?
    CLEAR($DARK)                       // Going to the daylight...
  ELSE
    AT($LAKE)
    SET($DARK)                         // Going into the darkness...

// Standard movements...

ACTION(_,_)
    TRYMOVE                            // Try to perform standard movements
    DESC                               //   through the Connections Section

// Here will be shown how pronouns (like "IT") may be implemented. This
// should to be coded before any action which requires a noun.

ACTION(_,IT)                           // W2 equal to "IT"?
    ISNULL($WHAT_IS_PRONOUN)           // No any nouns so far?
    MESSAGE(15)                        // Don't know what "IT" refer to...
    DONE                               // Stops further scaning
  ELSE                                 // Otherwise, set the noun to be equal
    COPYFF($WHAT_IS_PRONOUN,$NOUN)     //   to the last used noun

ACTION(_,_)
    COPYFF($NOUN,$WHAT_IS_PRONOUN)     // Save the current noun
    CANCEL                             // Signal "nothing concrete so far..."

// We want to make LOOK equal to REDESCRIBE, but LOOK _object_ equal to
// EXAMINE _object_ ...
    
ACTION(LOOK,_)
    SETVERB(REDESCRIBE)                // Set verb to REDESCRIBE
    ISNOTNULL($NOUN)                   // Noun recognized?
    SETVERB(EXAMINE)                   // If it is, set verb to EXAMINE
  CONTINUE
    CANCEL                             // Signal "nothing concrete..."

// Some very common entries...
                                      
ACTION(GET,I)
    INVEN

ACTION(I,_)
    INVEN
    
ACTION(R,_)
    REDRAW                             // Force redrawing the picture...
    DESC

ACTION(QUIT,_)
    QUIT
    NEWLINE
    TURNS
    END

ACTION(SAVE,_)
    SAVE

ACTION(LOAD,_)
    LOAD

ACTION(SCORE,_)
    SCORE
    TURNS

// Swimming is not allowed in this game...

ACTION(SWIM,_)
    AT($LAKE)                          // Lake?
    MESSAGE(18)                        // Water is icy...
    DONE
  ELSE
    MESSAGE(29)                        // No water here...

// In this game, we want to make the gold bar to be as heavy as 3 other
// objects. So, if the total number of objects conveyable is 4, the player
// should not be able to pick it up if he/she are carrying more than one (4-3)
// other object). The Quill does not allow specifying a weight of an object, 
// but such effects may be simulated by playing with Flag 1 ($NUMCAR) inside
// the entries for GET _object_ and DROP _object_ for each object which need
// to have a non-standard weight (greater than 1). After such manipulations,
// the scanning should continue through the standard getting/dropping
// procedure...

ACTION(GET,GOLD)                       // If the gold bar is here, and if more
    HERE($GOLD)                        //   than one object is carried, the
    GT($NUMCAR,1)                      //   player is carrying too much.
    SYSMESS(27)                        //   Otherwise, $NUMCAR is increased by
    NEWLINE                            //   2, so the bar will be as heavy as
    DONE                               //   3 other objects (AUTOG which will
  ELSE                                 //   be performed later additionally
    HERE($GOLD)                        //   increases $NUMCAR by 1 except if
    PLUS($NUMCAR,2)                    //   it fails)...

ACTION(DROP,GOLD)                      // Gold bar is heavy, so dropping it
    CARRIED($GOLD)                     //   (assuming that it is carried) 
    MINUS($NUMCAR,2)                   //   needs adjusting $NUMCAR too...

// Getting the snake is specific, because the snake is not coded as an object.

ACTION(GET,SNAKE)
    AT($TUNNEL)                        // Tunnel (snake is always there)?
    MESSAGE(10)                        // The snake bites your hand...
    SCORE                              // This was not a good idea!
    TURNS
    END

// Getting the key is specific too, because taking the key first time brings
// some points to the player.

ACTION(GET,KEY)
    ZERO($KEY_TAKEN)                   // The key was not taken before?
    SET($KEY_TAKEN)                    // Now, it is; give points for first
    PLUS($SCORE,20)                    //   taking, and continue scanning...

// "Lamp" is two objects in one...

ACTION(GET,LAMP)
    PRESENT($LIT_LAMP)                 // Lit lamp is here?
    GET($LIT_LAMP)                     // Well, get it...
    OK

// Standard gettings...

ACTION(GET,_)
    ISNOTNULL($NOUN)                   // The noun is recognized?
    AUTOG                              // Get the object, if possible
    OK
  ELSE
    MESSAGE(15)                        // Don't know what that is...

// In addition to the fact that the lamp is two objects in one, dropping the
// lamp (either lit or unlit) inside the castle is fatal...

ACTION(DROP,LAMP)
    AT($CASTLE)                        // In the castle?
    CARRIED($LIT_LAMP)                 // Lit lamp carried?
    DESTROY($LIT_LAMP)                 // Goodbye lamp!
    MESSAGE(31)                        // You broke the lamp...
    DONE
  ELSE
    AT($CASTLE)                        // In the castle?
    CARRIED($LAMP)                     // Unlit lamp carried?
    DESTROY($LIT_LAMP)                 // Goodbye lamp!
    MESSAGE(31)                        // You broke the lamp...
    DONE
  ELSE
    CARRIED($LIT_LAMP)                 // Otherwise: lit lamp carried (but not
    DROP($LIT_LAMP)                    //   in the castle)?
    OK                                 // Well, drop it...

// Standard droppings...

ACTION(DROP,_)
    ISNOTNULL($NOUN)                   // The noun is recognized?
    AUTOD                              // Drop the object, if possible
    OK
  ELSE
    MESSAGE(15)                        // Don't know what that is...

// Examining...

ACTION(EXAMINE,TREE)
    AT($LAKE)                          // At the lake (the tree is there)?
    NOTCREATED($KEY)                   // A key is not found yet?
    CREATE($KEY)                       // Create it
    MESSAGE(16)                        // Something falls to the ground...
    DONE
  ELSE
    NOTAT($LAKE)                       // Not at the lake?
    SYSMESS(26)                        // Can't see that...
    NEWLINE
    DONE

ACTION(EXAMINE,DOOR)
    AT($MOAT)                          // At the moat (the door is there)?
    MESSAGE(23)                        // Looks very strong...
    DONE
  ELSE
    SYSMESS(26)                        // Can't see that...
    NEWLINE
    DONE

ACTION(EXAMINE,LAMP)
    PRESENT($LIT_LAMP)                 // Lit lamp present?
    MESSAGE($LIT_LAMP)                 // Shining brightly...
    DONE

// An automatic action for examining all other objects...
    
ACTION(EXAMINE,_)
    WHATO($OBJ_NUM)                    // Find what is the referenced object
    ISNULL($OBJ_NUM)                   // Object recognized?
    MESSAGE(14)                        // Nothing of interest
    DONE
  ELSE
    WHEREO($OBJ_NUM,$OBJ_LOC)          // Find where is the referenced object
    NOTEQ($OBJ_LOC,$CARRIED)           // Not carried?
    NOTSAME($OBJ_LOC,$CURLOC)          // Not here?
    SYSMESS(26)                        // Can't see that...
    NEWLINE
    DONE
  ELSE
    MESFLAG($OBJ_NUM)                  // Display the associated message
    NEWLINE
    DONE  

// Other actions...

ACTION(EAT,RAT)
    CARRIED($RAT)                      // The rat is carried?
    DESTROY($RAT)                      // Goodbye rat...
    MESSAGE(13)                        // Not so bad (phew)...

ACTION(LAMP,ON)
    SETVERB(LIGHT)                     // Turn phrase LAMP ON to LIGHT LAMP
    SETNOUN(LAMP)
    CANCEL

ACTION(LIGHT,LAMP)
    NOTZERO($LAMP_HAS_GONE)            // The lamp has gone?
    NOTDONE                            // Sorry...
  ELSE
    CARRIED($LAMP)                     // Unlit lamp carried?
    ZERO($LAMP_COUNTER)                // Lamp hasn't been lighted before?
    LET($LAMP_COUNTER,12)              // The "life" of the lamp is 12 moves
    PLUS($SCORE,20)                    // Some points (and continue further)
  CONTINUE
    CARRIED($LAMP)                     // Unlit lamp carried?
    SWAP($LAMP,$LIT_LAMP)              // Make it lit
    MESSAGE(11)                        // It lights up...
    DONE

ACTION(LAMP,OFF)
    CARRIED($LIT_LAMP)                 // Lit lamp carried?
    SWAP($LAMP,$LIT_LAMP)              // Make it unlit
    MESSAGE(12)                        // It goes out...
    DONE

ACTION(EXTINGUISH,LAMP)
    CARRIED($LIT_LAMP)                 // Lit lamp carried?
    SWAP($LAMP,$LIT_LAMP)              // Make it unlit
    MESSAGE(12)                        // It goes out...
    DONE

ACTION(BREAK,DOOR)
    AT($MOAT)                          // At moat (door is there)?
    MESSAGE(25)                        // No effect...
    DONE

ACTION(BREAK,_)
    MESSAGE(28)                        // Nothing happens...

ACTION(UNLOCK,DOOR)
    AT($MOAT)                          // At moat (door is there)?
    CARRIED($KEY)                      // Key carried?
    SET($DOOR_OPENED)                  // Well, open the door...
    PLUS($SCORE,20)                    // Some points to the player...
    MESSAGE(8)                         // The door swings open...
    DONE
  ELSE
    AT($MOAT)                          // Otherwise: At moat (no key)?
    MESSAGE(24)                        // What with!?

ACTION(OPEN,DOOR)
    AT($MOAT)                          // At moat (door is there)?
    NOTZERO($DOOR_OPENED)              // Door open?
    MESSAGE(26)                        // Already open...
    DONE
  ELSE
    AT($MOAT)                          // Otherwise: At moat (door not open)?
    MESSAGE(22)                        // Locked...

ACTION(WAIT,_)
    MESSAGE(21)                        // Time passes...

ACTION(HELP,_)
    MESSAGE(27)                        // Sorry, no clues...

// Actions for turning pictures on or off...

ACTION(TEXT,_)
    PICOFF
    OK

ACTION(PICTURES,OFF)
    PICOFF
    OK

ACTION(PICTURES,ONCE)
    PICNORM
    OK

ACTION(PICTURES,_)
    PICON
    DESC

$$PICTURES

// +------------------+
// | Pictures Section |
// +------------------+

// Pictures in this game are captured from the original King's Ransom game for
// ZX Spectrum using the Warajevo ZX Spectrum Emulator by Zeljko Juric and
// Samir Ribic, converted to monochrome bitmaps (BMP) using Adobe Photoshop,
// then converted to a raw binary file using Image Studio by Matthew Johnson,
// compressed using the TTPACK tool from the TIGCC Tools Suite package by
// Thomas Nussbaumer, and finally converted to hex arrays using an another
// tool called TTBIN2HEX from the same package.

PACKED_BITMAP($BRIDGE,160,80,$CENTER,0,81)
    0x4006,0x5450,0x1504,0x0000,0x3D02,0x0880,0x0000,0x0015,0xFFAA,0x2255,
    0xEFEE,0x0888,0x8ADD,0x0002,0x5775,0x8FAB,0xBABF,0xEAF7,0xFE1F,0xC751,
    0xFD5F,0x5F8E,0x2BFF,0xEE84,0x763A,0xFEBA,0xFABF,0xA381,0xD55D,0x5719,
    0xFA1F,0x8E82,0x1D1E,0x1EAA,0xAAF0,0x3D03,0x6471,0xDD77,0x7F51,0x17F5,
    0x743A,0x1B31,0xFC9F,0xAFAF,0xE315,0xD55D,0x7904,0x7EBE,0xAABE,0x56BB,
    0xFA3F,0xD75D,0x58CF,0xB1C9,0x4494,0x1B17,0x647A,0x8DE0,0x4F85,0xD71C,
    0x0588,0xD8D7,0x1178,0xD857,0x2335,0xFF5E,0xE7A8,0x2FC6,0x7D0E,0x78FF,
    0x2683,0xEBAC,0x701E,0x39FF,0x3AAF,0xE545,0x10F4,0xFEEA,0x1EE5,0x57AB,
    0xDFDD,0x710F,0x3444,0x6475,0x0F57,0xE95F,0x007D,0xF988,0x0D77,0xFB28,
    0x778C,0x40F5,0xB1E3,0x8FFE,0xFB01,0xE06C,0x6EDD,0xFD0F,0x34D3,0xBCAA,
    0x6FBD,0xFD63,0xC4B0,0xEF1E,0x60F1,0xC078,0x8051,0xABEA,0x8078,0x1B17,
    0xFF54,0x43B4,0x4C0E,0xDDCD,0x586B,0xFAA9,0x61F0,0x2211,0x0BB9,0xA6C0,
    0x8096,0x1773,0x16D8,0x527A,0xC5A3,0x06EA,0x949C,0x3890,0x2B80,0xFFFF,
    0xC1CB,0x62FF,0xBEAD,0xAAF0,0x03F3,0x7801,0xF9BC,0x0746,0x0F75,0x2A38,
    0x4388,0x1900,0x040D,0xB958,0x6FB1,0x60BC,0x48FC,0xB888,0x7ED6,0x1762,
    0x9860,0xDDF7,0x54AD,0x8438,0x1FF8,0x000F,0xFCB0,0x3C3D,0x9F76,0xF2DD,
    0x5B65,0xED11,0x391D,0x0E76,0x4867,0x6017,0x1617,0x7A98,0xDD55,0x5689,
    0xFF07,0xFE3B,0x2ECA,0xB60F,0x7EA9,0x0BE5,0x953F,0x75AC,0xFAA6,0xD880,
    0x97FF,0x12E4,0x2AFF,0x5F0E,0xEABA,0xD560,0x0BA0,0x0742,0x63CD,0x878F,
    0x0D80,0x21FD,0x3F32,0x17DD,0x93F1,0x1FF1,0x2BFC,0x83D3,0xB00E,0xFF5F,
    0x9960,0xBAAE,0x0E80,0x1D07,0xC584,0xCF97,0x61FE,0x8F87,0x3415,0xBD55,
    0xD575,0x3111,0x3303,0xC708,0xB0B0,0xF7D5,0x0D76,0x6C01,0x06C1,0x3086,
    0xC381,0x96C4,0x3F5F,0xD8E7,0x86FB,0x885D,0xB44C,0x6444,0x2FFE,0x5D9A,
    0x2BE3,0x2363,0x5558,0x8D86,0xD0D8,0x7132,0xECE3,0xEF1D,0xD77A,0x5474,
    0x5DEC,0x545C,0xE440,0xA2A9,0x0582,0xFEF0,0xF769,0x6B1F,0xD428,0x8806,
    0x0192,0x9396,0xC60A,0x5855,0xD7D5,0xFF75,0x2582,0xB84E,0xE8DC,0x3C46,
    0x523D,0x15F8,0xFBEB,0x81B3,0xF6A2,0xEEB3,0x0BAA,0x09A4,0x447F,0xDFFF,
    0x77F1,0x25E7,0x6F77,0x4F77,0x5FE5,0x555F,0x507E,0xD583,0x06EB,0xABEE,
    0xFAFB,0xAAF6,0xBD0A,0xAACC,0xA438,0xA1D6,0x0001,0x7CC7,0xFEFF,0xBEA4,
    0x777F,0xFEFD,0x7D77,0x4375,0x7F29,0x75F5,0x7C2B,0xE2A9,0xBC5F,0x3EFB,
    0xABEA,0xFADF,0xB458,0x2AAB,0xBA6A,0xBACD,0x8155,0x7A2C,0x22C6,0x85C8,
    0xFD6D,0x8FC7,0x89E3,0x5367,0x8EB5,0x601B,0x800F,0xF986,0x395C,0x3567,
    0x70AF,0x8FF7,0xD539,0x24DE,0xA43E,0x083B,0x147B,0x9FBF,0x5E1D,0xFE6D,
    0x6C03,0x9FFF,0x298E,0xFD04,0x2475,0x1C18,0x33DC,0x362B,0x964F,0x7EAC,
    0xFC75,0x603F,0x5AD8,0x0159,0x96BA,0x8075,0x7E3A,0x9AE6,0x58B4,0xB822,
    0x2F74,0xD8DF,0x4D80,0x557A,0x32BA,0xBA71,0x579B,0x5A7E,0x737B,0xBFFA,
    0xFFEE,0xFBDC,0xDCBF,0x80A8,0x1FA7,0x2D8D,0xD98C,0x45B9,0x6AEC,0x0038,
    0x6B83,0xB144,0x0692,0x5F77,0x4D36,0xDF2E,0xCF85,0xBA1F,0x31B0,0x84BA,
    0x62EB,0x7552,0xA29F,0xDA82,0x6B68,0x07C1,0x8885,0xB2D6,0xCF52,0xF32F,
    0x02AA,0x23DA,0x7A5C,0xE5B8,0xA5C7,0x7435,0x8D15,0x3C24,0x47DA,0xE3EF,
    0xE97B,0x9785,0x4444,0xE961,0xBFEA,0xB763,0x14E1,0x7935,0xD4E7,0xFAB8,
    0xFEBF,0x69AA,0xBD3F,0x5725,0xF054,0x447F,0x7A30,0x6EEC,0xE631,0xBC0A,
    0xA358,0x0101,0xA810,0x0DC0,0x4307,0x58CB,0xB2AC,0x6BC9,0x138A,0xF8BE,
    0x1410,0x1F5E,0xFEBA,0xA233,0x854C,0x9EB1,0xB151,0x9C6B,0x81AE,0xF741,
    0xC583,0x148B,0xFFCC,0xB603,0x5C41,0x6020,0xA333,0xF860,0x79FF,0x0041,
    0xE15A,0xFC7B,0xB77D,0xC597,0xC46C,0x0075,0x5DD0,0xF12F,0x8181,0xDCC3,
    0x8848,0x0273,0x9000,0xB20E,0xF080,0xE879,0x5DD6,0x9FAE,0x5EB5,0x7DFA,
    0xEE87,0x858A,0xE300,0x0678,0xF59F,0x0DE9,0x5FBE,0x6D3E,0x6AAF,0x08F5,
    0xF02D,0xE4BF,0xEBFE,0x5D5F,0xBC5B,0x09E1,0x9F2A,0xA5F5,0xD2DD,0xD7C9,
    0x53F4,0xDD49,0x7F1F,0x192F,0x14BD,0x7175,0x767E,0xAA7D,0x7AB4,0x071C,
    0x2C23,0x43EC,0x2BF9,0xB23B,0xAAAF,0xEFB1,0x8959,0x048C,0x2D72,0x8F81,
    0xD555,0x2A70,0xE0B0,0xFD55,0x5785,0x8306,0x53A9,0x82AE,0xFE0C,0x7A47,
    0x8F98,0xBFFF,0x8000
END_PACKED_BITMAP

PACKED_BITMAP($CAVE,160,80,$CENTER,0,81)
    0x4006,0x5450,0x5304,0x0000,0x3D01,0x0880,0x0000,0x0012,0xFF55,0xAAEE,
    0xEF00,0x08EA,0xFE81,0x888F,0xAED7,0xE3F5,0xF7FB,0x3F8E,0x81FA,0xBEBF,
    0x38AF,0xFFB8,0x23B3,0xAFEA,0xAEAB,0xF372,0xD52D,0xD57B,0x2BF6,0x7E3A,
    0x0EDE,0x15EA,0xAAAF,0x403D,0x06C9,0xC775,0xDDFD,0x4105,0xFD5D,0x1D1B,
    0x241F,0xC9FA,0x5FAF,0xF62B,0xAABA,0xD721,0xFAFA,0xAAFE,0xB5DF,0xD1E9,
    0xE3AA,0xACCF,0xB396,0x8892,0x86C5,0xDABD,0x6AC9,0x3E17,0x5CE0,0x589A,
    0x6B95,0x7DA2,0xBE33,0x5FE9,0x5EE7,0xA85F,0x99F4,0x7387,0xE4D0,0xFAEB,
    0x381E,0x39FF,0x3AA5,0xFFA8,0xAC3D,0x3FBA,0xCF7D,0x57AB,0xD1FD,0xD1F8,
    0x1FDD,0x45AF,0x5BAE,0xEAB5,0xAAEE,0xBB4B,0xE4EF,0xBBAE,0x4EBB,0xBEE4,
    0xFA3C,0x8289,0x2EFF,0x7777,0x9B1D,0xE3EB,0xFD1F,0xA3E0,0x7D2B,0xD46F,
    0xEF86,0x4DF1,0xB9FA,0x4EE4,0xFBBF,0xEE4B,0xA66E,0x8A3D,0xDBBF,0xBBEA,
    0xA1FD,0xF777,0x55DF,0x77DD,0x57F6,0x65F7,0xD0F3,0x1C7B,0xBAA5,0xBF5E,
    0xABEE,0xB106,0x9FF5,0x4954,0x680D,0x81E8,0x2C0E,0xE15F,0x6622,0xA457,
    0xABF3,0x5774,0xBF6D,0x1DD5,0xE97C,0x9D46,0xC7B8,0x650B,0xA1E8,0x6C5F,
    0xFDDD,0x7557,0x7D85,0x9FAB,0xFFF4,0x587D,0x0B0E,0xA13D,0xAFEF,0xAA4E,
    0xA4AF,0xFA4A,0xBEA8,0x31DD,0x11DB,0xA8B0,0x1F46,0x1B88,0x5E45,0xC982,
    0xA992,0xC860,0xDD2F,0x5B48,0x8B5A,0xEBB0,0x55D5,0x762E,0x3FBB,0xBAC2,
    0xEA3F,0xEEEA,0xBAAA,0xABAE,0xFEAA,0xBFFE,0x1F15,0xF757,0xFD75,0x5D68,
    0x60F5,0x34F5,0x0702,0x47F4,0x7B93,0xE8AA,0x1600,0x9CC5,0x3120,0x6834,
    0xF71C,0xE3FE,0xAF7D,0xD110,0x4BA9,0x26C2,0xF236,0x057A,0xB635,0xC9F4,
    0x7475,0x1AF5,0x75F7,0x8B4E,0xE35B,0xF616,0x0477,0xB1BA,0x4AA3,0x6059,
    0x6F8D,0x8F73,0x4070,0x888D,0x723D,0x08CA,0x6C40,0xC22C,0x3B95,0x6014,
    0xEFFE,0x0BDE,0xB558,0x0361,0xAC38,0x8674,0xAA29,0xBD49,0x7F77,0x5758,
    0x87FF,0xBEEA,0xE008,0x0FEA,0xAAEF,0xAEBF,0xEC5A,0xA5D3,0xBEEB,0xAB2B,
    0xFAFC,0x9CE0,0x002F,0xAEB4,0xBE2D,0x35F5,0x77CB,0x7DD7,0x154A,0xE7F8,
    0xC09D,0x985D,0xB675,0x5780,0x7B66,0x5853,0xB92B,0x1B42,0x1057,0xA2C0,
    0x31EA,0xA2C3,0x5E1F,0x8FEE,0xB076,0x575D,0x5DD5,0x8B0A,0xBFFE,0xA458,
    0x7555,0x9BBF,0xB92A,0x0EC0,0xBA4E,0xA888,0xD746,0xC0FD,0x376E,0x317B,
    0xD03B,0x09B9,0x0CEE,0x2B0F,0xBC3D,0xF2D8,0x9D8A,0xEBAB,0xEFB8,0x88A7,
    0xFF70,0x7022,0x35F0,0x78FE,0xAA07,0x6115,0x552A,0xC3A8,0x1B32,0xB0F1,
    0xF72D,0x8545,0x5378,0x1B2E,0x29F7,0xDC9F,0xCDE0,0x456E,0xBC7F,0xDFF7,
    0x40E2,0x3615,0x64A0,0x7502,0x060D,0xF2D9,0x5551,0xC934,0xFB5A,0xF5EE,
    0xAFAB,0x0775,0x5771,0xFA7B,0xEEAE,0x35AB,0x375F,0xAAFE,0xEEB3,0x2ABF,
    0xFAC5,0x85FF,0xC897,0x2510,0x7417,0xF777,0xD0C0,0x2C16,0x3822,0xC0D8,
    0x5592,0x9885,0x730A,0xDEF6,0x0704,0x6A68,0x8D8F,0x527D,0x014B,0x6A31,
    0xFCFB,0xAAA0,0x8880,0x585F,0x7D0D,0x635A,0xF458,0x5D55,0xF3F9,0xEF96,
    0xB220,0x89AE,0x2217,0xE9DC,0x46A5,0x0527,0x71EF,0x9FF6,0x2EEA,0x33BB,
    0xD9A6,0x8906,0x56E1,0x7F84,0x22D7,0x1144,0xB929,0x756A,0x987F,0x5B51,
    0xBFFF,0xF756,0x4511,0x44D6,0x042F,0xBBFE,0xABBB,0xAFAA,0xFFEF,0xBBAA,
    0xD2D4,0x16AC,0xB08C,0x38DA,0xAFD7,0xFCBE,0x50D5,0x7D5F,0x69D5,0x6714,
    0x37D3,0x72AD,0x0EE5,0x8A61,0xBFEF,0xAB22,0x49E4,0xFFBF,0xAA4B,0xA180,
    0x0B2D,0x0814,0x1FA2,0xC3AA,0x1FC0,0x8009,0xE90C,0x895F,0x7E91,0x61DE,
    0x98DA,0xF7F5,0xF806,0xE42A,0x9697,0xF4E4,0x25F4,0x6C6B,0xEF86,0x5FEC,
    0x8373,0x8E1F,0x5DEC,0xE36D,0x4123,0x9CBF,0x5026,0xC01D,0xA4B5,0xD6CC,
    0xC95D,0x9EF6,0xF151,0xF600,0xEC20,0x1AAB,0xA458,0x0B25,0xA06B,0x4C3F,
    0xFC11,0xD868,0x3E09,0x7CE8,0x5813,0xBFEA,0x39FB,0x0DB2,0x89C9,0x9579,
    0x6DC6,0x8CCA,0xB973,0xC1D5,0x7035,0x75AB,0x0AFD,0xB709,0x7350,0x0007,
    0x503E,0xEA56,0xCF8A,0x3BFB,0xEB1B,0x0685,0xF80F,0x8FBB,0x34BF,0x01AB,
    0xDDFD,0x76EE,0x34CB,0x5DFC,0xE35F,0x82E5,0x6FDE,0xA2BB,0xFBED,0x6ABB,
    0xDD8E,0xEFF4,0xBB57,0xD479,0xA864,0xAAEF,0x3B6B,0xFB83,0x01F2,0x84AF,
    0xFE4F,0xAA0C,0xDDFF,0x3E58,0x48E6,0xAA2E,0xFD7D,0x53E5,0x0C56,0x912E,
    0x9E95,0xE7CD,0xF9AA,0x7847,0x9F01,0xBC37,0xFD7F,0xC757,0xEE2E,0xC1E1,
    0x9F2A,0x4BE7,0x46E8,0x7C95,0x3F41,0x811C,0x857C,0x6178,0xD07D,0xC456,
    0x3F67,0xAD7D,0x680E,0x3878,0x3B25,0x7D33,0x6401,0xA38E,0xF983,0xBB20,
    0x9616,0x3DE4,0x1F02,0x181D,0x139F,0xA182,0x1604,0x32BA,0x982A,0xAFE0,
    0x4F48,0xF3E6,0x5FFF,0xC000
END_PACKED_BITMAP

PACKED_BITMAP($TUNNEL,160,80,$CENTER,0,81)
    0x4006,0x5450,0x1804,0x0000,0x3D01,0x0880,0x0000,0x0012,0xFF55,0xAAEA,
    0xEFFB,0x0008,0x575D,0x7781,0x8FBF,0xDFE3,0xEEF7,0x3F8E,0x81FA,0xBEBF,
    0x38AF,0xFFB8,0x23B3,0xAFEA,0xAEAB,0xF374,0xD52D,0xD57B,0x2BF6,0x7E3A,
    0x0EDE,0x15EA,0xAAAF,0x403D,0x06C9,0xC775,0xDDFD,0x4105,0xFD5D,0x1D1B,
    0x241F,0xC9FA,0x5FAF,0xF62B,0xAABA,0xD721,0xFAFA,0xAAFE,0xB5DF,0xD1E9,
    0xE3AA,0xACCF,0xB396,0x8892,0x86C5,0xDABD,0x6AC9,0x3E17,0x5CE0,0x589A,
    0x6B95,0x7DA2,0xBE33,0x5FE9,0x5EE7,0xA85F,0x99F4,0x731F,0x9343,0xEBAC,
    0xE078,0xE7FC,0xEA97,0xFEA2,0xB0F4,0xFEEB,0x3DF5,0x5EAF,0x47F7,0x5D47,
    0x2D79,0xC751,0xF0BD,0x44AF,0xEFBB,0xAE4E,0xA228,0x5A88,0xB3D3,0x5C97,
    0x7F85,0x9F75,0xD555,0xD30D,0x3FE3,0x1059,0x55FF,0xBE4F,0xFEE4,0xEBBA,
    0x722B,0x63F4,0xC275,0x1444,0xAFBA,0x86DA,0xBEE4,0x6C57,0x555F,0xFF55,
    0xAB6C,0x077D,0xEFFF,0xFB97,0xEAED,0xE22F,0xD3AA,0x2075,0x469B,0x2B05,
    0x30F7,0x0571,0xF836,0xC7D7,0xF7DA,0x39FD,0x5110,0xAD62,0x7FF5,0x1ABF,
    0xBAA4,0xAA6E,0x64BA,0x897B,0xB432,0xA2B0,0x6C5D,0x57A1,0x6AEF,0xBFEC,
    0x08FB,0x92E8,0xE337,0x2257,0x46C0,0x30FB,0x1584,0xBBBF,0xBA67,0xDDD9,
    0xAD71,0xAA01,0xFE86,0xD884,0x1B01,0x8112,0xE8D8,0x340C,0xC3D4,0x9549,
    0x6FFF,0x77DC,0x9DF7,0x4587,0xD572,0xB60D,0x519D,0xD43C,0xBFBB,0xAFD0,
    0xC011,0x1474,0x688D,0x815E,0x8A23,0x7738,0xEB53,0x10FB,0x46C0,0xAD1E,
    0x63EC,0x6020,0xE1A6,0xC0D9,0x380C,0x5FE4,0xFAA3,0x80C5,0x5672,0x9BB2,
    0xC9BB,0xE1FA,0x5775,0xB188,0x8B4B,0x7185,0xEBF5,0xBFAD,0x85D9,0xF67B,
    0x4F42,0x5AE9,0x0737,0xD77F,0x57E0,0xE956,0x15FF,0xD7FF,0x04FF,0xEE4B,
    0xE727,0xFEBE,0xEB32,0x609D,0xC591,0x0F8B,0x0493,0x26A2,0x32FA,0xBEFC,
    0x7A77,0xFF75,0x9847,0xFF8A,0xB034,0xBFFD,0x2772,0x5FF7,0x3ADD,0x1604,
    0x7E39,0x10C6,0x6C5F,0x8FBE,0xFFB4,0x6C06,0x21F6,0x2C3F,0xFD55,0x61BF,
    0xEFBE,0x4BE1,0x7D0B,0xA4EE,0x643F,0x1896,0xBE40,0x8F7A,0x2C10,0xEBDF,
    0xDC2B,0xBFCD,0xE048,0x6072,0x0B41,0x104F,0xA8D8,0xDD46,0xC71F,0x7ACE,
    0x81FC,0x3E90,0xCE2D,0xBBEE,0xD107,0xF786,0x3975,0x55B0,0x2DC1,0xA93F,
    0xA187,0x5CCC,0x1189,0xDF7C,0x97F0,0xDA07,0x37E8,0xD8AE,0x5587,0x8888,
    0x27D5,0x1C25,0xC946,0xC6FA,0xAC23,0xC37F,0x77D9,0xB1D6,0x6D7F,0x0A64,
    0x8EEA,0x8843,0x00DF,0x3906,0x922D,0x89FF,0x7F5F,0xDD16,0x043E,0x362E,
    0x81ED,0x5558,0xD911,0x0742,0xA51B,0x1F22,0xD89D,0x7D4D,0x3ED1,0x61BE,
    0x3610,0xC1FA,0xAB0A,0xFBBF,0xA46C,0x20E0,0xE2BE,0xBBAD,0x017C,0x691C,
    0x3759,0x4429,0x6097,0x49D4,0x6C63,0xF9A4,0x7042,0xFFDF,0x70B0,0xEEBB,
    0x5528,0xD1E7,0xF344,0x413B,0xA0E1,0x1103,0xF497,0x47AE,0xE8FA,0xCF48,
    0x59F7,0xDE6C,0x7FF5,0xA625,0xD0B2,0x3447,0x9242,0xC480,0xC2DB,0xDC58,
    0x12B9,0x9AE2,0x949D,0xD8BF,0x1DF5,0x68BA,0x5981,0xDE04,0x4D6F,0x98B5,
    0x02C1,0x0BE4,0xFE91,0xC0F0,0xFDF7,0x01CB,0x8934,0xAFFD,0x66F0,0xD7F5,
    0x00DB,0xF48C,0x421F,0x7D17,0x7BE5,0xEAAA,0xFAAF,0x4BA4,0xBE34,0x8E37,
    0xC7DA,0xC7CB,0xBEE0,0x6E05,0xEEAB,0xFEEB,0x925E,0xF78D,0x30EA,0x838D,
    0xF27D,0x4B56,0x8D8D,0x7487,0x888B,0xDFEF,0x45F7,0xDA63,0xA454,0xF7F7,
    0x0DB4,0x8347,0x4B7E,0x0975,0x3118,0x4EE3,0x4547,0x01FF,0xDD6B,0x25D8,
    0x4002,0xE180,0x08D7,0x0F51,0x5A62,0xE240,0xBD55,0xF086,0xAB93,0x8E97,
    0x514B,0xEFFA,0xA88F,0xE41C,0x5D75,0x0854,0xB415,0xF748,0xF2EB,0xEFDF,
    0x5C48,0x20D4,0xB771,0xA8AE,0xBB92,0xF61C,0x53E8,0x8EAE,0xAABB,0x55A7,
    0x58FD,0xFA65,0x53D7,0xBFFA,0x1949,0x5511,0xEAD4,0xDD66,0x7412,0xEF77,
    0x59C7,0xF7D0,0xDF01,0x23EC,0xE616,0x606F,0x93FB,0x05C0,0xC8B0,0x658C,
    0xF292,0xFEED,0x59E5,0x568A,0xAEE4,0x5822,0x96E8,0x3013,0xF9ED,0xFAC0,
    0xE170,0xD07C,0x5F4C,0x0E04,0x09B3,0xAE7C,0x5AA3,0x7194,0x41E9,0x5E7C,
    0xDF9A,0xA784,0x79F0,0x1BC5,0x7E97,0x80E2,0xFDC5,0xD83C,0x33E5,0x497C,
    0xE8DD,0x4F92,0xA420,0xD523,0x90AF,0x8C2F,0x1B0F,0xB8AA,0xAAAB,0x3F67,
    0xD43D,0x7F0E,0x3878,0x3B25,0x7D33,0x6477,0x2ABF,0xBE60,0xEF02,0x0938,
    0x4B02,0x41F0,0x3AA5,0xABE8,0x9CAF,0xD555,0x7A05,0x810C,0xAEA6,0x0AAB,
    0xF813,0xD23C,0xF997,0xFFF0
END_PACKED_BITMAP

PACKED_BITMAP($LAKE,160,80,$CENTER,0,81)
    0x4006,0x5450,0xB203,0x0000,0x3D02,0x0880,0x0000,0x0014,0xFFAA,0x5588,
    0xEE08,0xBAEF,0x0022,0x4557,0x758F,0xABCE,0xDDEA,0xEBF7,0x1FC7,0x51FD,
    0x5F5F,0x8E2B,0xFFEE,0x8476,0x3AFE,0xBAFA,0xBFA3,0x81D5,0x5D57,0x19FA,
    0x1F8E,0x821D,0x1E1E,0xAAAA,0xF03D,0x0370,0x1C77,0x5DDF,0xD445,0xFD5D,
    0x0E83,0xC23F,0x93F5,0xF5FC,0x62BA,0xABAF,0x208F,0xD7D5,0x57CA,0xD77F,
    0x47FA,0xEBAB,0x19F6,0x3928,0x9283,0x62EC,0x8F51,0xBBA7,0xC2EB,0x8E02,
    0xC46B,0xAE22,0xF1AA,0xB919,0xAFFA,0xF73D,0x417E,0x33E8,0x73C5,0xF934,
    0x1F5D,0x6380,0xF1CF,0xF9D5,0x7F2A,0x2887,0xA7F7,0x50F7,0x2ABD,0x5EFE,
    0xE87E,0x07F7,0xD2BE,0x00FB,0xF114,0x1AEF,0xF644,0xFBE8,0x2BFF,0x7D02,
    0xE8DB,0x0AA3,0x6376,0x4F6F,0x5620,0x0E84,0x001F,0xDEFB,0xD961,0xC100,
    0xD582,0xFAE1,0x3C62,0xFFF5,0x5EED,0x81C4,0xD8BF,0x7ABB,0x0415,0x6041,
    0x161A,0xF737,0x6009,0x803B,0x8C58,0x6EFF,0xDD0C,0x0181,0x1FC1,0x017F,
    0xF754,0x4060,0x07C5,0x0C17,0x5580,0x7E07,0x0005,0xDCC0,0x1FC1,0x4766,
    0xFFFD,0xD4C1,0xF1D1,0x910C,0x1BB7,0x53A0,0xFD1B,0x0FBF,0xD757,0x6461,
    0xC902,0x0EEF,0x61EA,0xEC03,0xFF87,0xC33D,0xFAC8,0x0E5F,0x1D04,0xA7F2,
    0xCCAB,0xFF85,0x60AA,0xAA7C,0x4700,0xF03A,0xBFFC,0x021F,0xFEEB,0x911D,
    0x59C1,0xDA18,0xDFA4,0x265F,0xFE6A,0xA8AA,0x9C5B,0x2308,0xEC13,0xFFF7,
    0x7757,0x72F1,0x8AA5,0xB119,0x3912,0x9691,0x1169,0xF8C6,0xC388,0xDAA5,
    0x0622,0xEE00,0x47D8,0xD887,0xEBFA,0x5B76,0x0D76,0x5940,0x27E2,0xAC00,
    0x807E,0x07E5,0x07D7,0xC7AB,0x3550,0x0588,0x5058,0xAA05,0x0020,0x8AD9,
    0x987C,0x7DFD,0xDD9D,0xDD05,0xD15A,0x1DCD,0x9019,0x2881,0x8A98,0x02FE,
    0xF0E8,0xD851,0xA354,0x562A,0x9450,0x2A38,0x9200,0x1E0A,0xDE3A,0x9AB4,
    0xFEAB,0xA02B,0xA3A1,0xABA8,0x63B3,0xF93F,0x7AFC,0x58D8,0x56A7,0x5AA8,
    0xB9FA,0xA9D7,0x6180,0x9C7E,0xAEE8,0xB0EE,0x6EAB,0xEE77,0x3D12,0x8FFE,
    0xE8EF,0x860C,0x1A2C,0x8568,0xD59C,0xE755,0x4FFA,0x8AB8,0xFFDF,0x549A,
    0x979D,0xC555,0x35EE,0x77FD,0x7577,0x7FF3,0x8000,0x2ABE,0x5552,0xFFF1,
    0xFB16,0x1D53,0x49DC,0xB74E,0x7827,0x33DF,0x0013,0x70E3,0xA498,0x65F2,
    0xF596,0xED52,0x5489,0xA531,0xD2EF,0x6936,0x91DA,0xD8AF,0x5F57,0x7F9E,
    0xFA6C,0x03AF,0x974F,0xFD75,0x2BE7,0xFDF5,0xFD55,0x55AF,0xB3F7,0xC47E,
    0x0005,0x7C7C,0x3BFF,0xE9FA,0x9F9F,0x774B,0x45F6,0x6FE6,0x2B1D,0x0000,
    0xD77C,0x3AB1,0xE63B,0xBECC,0x70CD,0x7BFD,0xF078,0x66E9,0x7FCA,0x014A,
    0x0001,0xAED6,0x3B80,0x07EC,0x4EFF,0xF55D,0x773C,0x4BF5,0x4D66,0xFDFF,
    0xF944,0x6200,0x00BA,0x31B2,0x4BEE,0xB18B,0xDFDD,0xD6E1,0x0E8B,0x48B3,
    0xFCC7,0xE75A,0xEB31,0x5487,0x31C4,0x0A23,0x28C4,0x011C,0xCA36,0x4318,
    0xE8AF,0xFB8D,0xF937,0x2E44,0xD2AE,0xEABB,0x6352,0xEEF9,0x8EDD,0xFE19,
    0x0C64,0xE003,0x0010,0x1452,0x2001,0x8320,0x54A7,0x7B11,0x1F6C,0x4438,
    0x6AB5,0xF557,0xF77C,0x9D9D,0xE870,0xA631,0x9E06,0xB79B,0x56C0,0x01E3,
    0x00C6,0xD363,0xAFA9,0x8B8A,0xFEA5,0xE627,0xAB15,0x5FFD,0x7BFE,0x6118,
    0xC7FF,0x8EAB,0xFAB8,0x0984,0xA634,0x4DFE,0xBBDC,0x41C7,0x5558,0xF501,
    0x588F,0x2212,0xDCE6,0x3303,0x7FFC,0xCB60,0x58C8,0xCE02,0x84CF,0xFA5D,
    0xBB6C,0xE868,0xDD72,0x7F55,0xDDD5,0x75A1,0x9230,0x293D,0xCACC,0x0601,
    0x986B,0x8019,0x8420,0x11FF,0x40DF,0xE5EA,0x242A,0x1CF5,0x5723,0x0258,
    0x77BC,0x3030,0x30E1,0xF5E7,0x39CC,0xA3F5,0xD1E8,0x7483,0xBF9A,0xA3C2,
    0x3C7C,0x0379,0x2FFA,0xFF87,0x57E7,0x16C0,0x7867,0xCAAF,0x8E86,0xEC3E,
    0x4A9F,0xA2EA,0x4BF8,0x5FC6,0x5BC7,0x22FD,0xC5D5,0xD9FB,0x3E85,0xCAD0,
    0x10E3,0x819C,0x1718,0x57F3,0x6477,0x155F,0xDF30,0x3B88,0x930B,0x1EF8,
    0xF81D,0x5552,0xA70E,0x0B0F,0xD555,0x7858,0x3065,0x3A98,0x2AEF,0xE0C7,
    0xA478,0xF98B,0xFFF8
END_PACKED_BITMAP

PACKED_BITMAP($MOAT,160,80,$CENTER,0,81)
    0x4006,0x5450,0x2004,0x0000,0x3D02,0x0880,0x0000,0x0011,0xFFAA,0x5508,
    0x88AB,0xEE00,0x2257,0x8FBA,0xBBDD,0xEAEF,0xF71F,0xC751,0xFD5F,0x5F8E,
    0x2BFF,0xEE84,0x763A,0xFEBA,0xFABF,0xA381,0xD55D,0x5719,0xFA1F,0x8E82,
    0x1D1E,0x1EAA,0xAAF0,0x3D03,0x7807,0x1DD7,0x77F5,0x117F,0x5743,0xA0F0,
    0x8FE4,0xFD7D,0x7F18,0xAEAA,0xEBC8,0x23F5,0xF555,0xF2B5,0xDFD1,0xFEBA,
    0xEAC6,0x7D8E,0x4A24,0xA0D8,0xBB23,0xD46D,0x27C2,0xEB8E,0x02C4,0x6BAE,
    0x22F1,0xAAB9,0x19AF,0xFAF7,0x3D41,0x7E33,0xE873,0xBFE4,0xD07D,0x758E,
    0x03C7,0x3FE7,0x55FC,0xA8A2,0x1E9F,0xDD43,0xDCAA,0xF57B,0xFBA1,0xF81F,
    0xDF4A,0xF98C,0xE2D9,0xD600,0x1C0B,0x06F8,0xF003,0x5DD3,0xF660,0x41CE,
    0x005C,0x00E2,0xF8E0,0x2BFF,0x7D4F,0xED68,0xC00B,0xC03C,0x5B1B,0xB77E,
    0x6C7C,0x84E0,0x0829,0xC1E2,0xECFB,0xDFF3,0x6378,0x20E0,0x4039,0xE8B0,
    0x6BB0,0x3E40,0x0721,0x7BCC,0x5FFE,0xAB87,0x6007,0x800A,0xAF2E,0x2D89,
    0x5FC1,0x9D13,0x8003,0xC021,0xD715,0x86BF,0x9A00,0x0200,0x4F00,0x0E08,
    0x0E05,0xC111,0x1B91,0xE880,0x103C,0x007A,0x0071,0x3D60,0x2E18,0x33A8,
    0xD808,0x01E0,0x07C0,0x1CB8,0x3624,0xFEE1,0xD896,0x09B2,0x2EF1,0x3072,
    0xC035,0xD89A,0xE1E3,0x6E46,0xA080,0x7BFF,0xFDAE,0x1D89,0xAF13,0xB3D0,
    0xBB98,0xEEE4,0x60DD,0xF372,0xEC19,0xF039,0x705E,0x0554,0xBA9B,0xEFF6,
    0x1705,0x1D90,0xC64C,0x3C1E,0xE757,0x6054,0xAEA6,0xEBB1,0x8957,0x60A8,
    0x060C,0xA07B,0xFC78,0x28EC,0x1555,0x573D,0xFAF9,0xAB10,0xBE48,0x278A,
    0x6819,0xD998,0x5B19,0x05DD,0xFDD7,0xFF0A,0xB2AB,0xB0FF,0x08FC,0x4027,
    0x8D9E,0x0C55,0x1575,0x5587,0xFFBC,0xA4A0,0xC761,0x7432,0x9FE4,0x022F,
    0x8E88,0x02EA,0x5735,0x7FF9,0x9660,0xC761,0x442F,0xFF40,0x711C,0x7100,
    0xAA94,0x54AE,0x9607,0xFFD9,0x5F0C,0x761C,0xC67F,0xEC77,0x547E,0x5457,
    0x2E6F,0xBD2C,0x34DA,0xD82E,0x884E,0xCA92,0x051F,0x0880,0x76BB,0xC3F5,
    0xF18B,0xE3AE,0xC8F8,0xC78A,0x950D,0x3810,0x1D2E,0x74BB,0x4EDE,0x2DC6,
    0xBB23,0x3F98,0xEC55,0x810A,0x8CE5,0x57E3,0xEFCA,0x5CA9,0x8249,0x9DF7,
    0x1DDB,0x1105,0x1D4D,0x587D,0xE1E2,0x2999,0x8EC3,0x80CD,0x7B40,0xED8C,
    0xC355,0xDA07,0x83D7,0xE312,0xD9F8,0x1954,0xA740,0x8C9F,0x22B4,0x635A,
    0x55A7,0x6F84,0x8B87,0x66B2,0x9B18,0xEC25,0x52A3,0x6564,0x7FDF,0xC4EC,
    0x031D,0x81FF,0xDD81,0x353F,0x7F4B,0xB10E,0x3E32,0x551B,0x8147,0x6046,
    0xFCAB,0x0309,0x7810,0x2C48,0x41FF,0xBCC6,0x6406,0x08EC,0x0493,0xDDE0,
    0x6135,0x7D53,0x96C7,0xCFA6,0xB703,0x5D89,0x6013,0xC8E6,0x04B1,0x61F2,
    0x7AA2,0x0782,0x3B3B,0x83B3,0x2BE8,0xCB63,0xBF8F,0xC6E2,0x41C0,0x8EC1,
    0xD781,0x96C6,0x3FDE,0x4B2D,0xC261,0x5D9D,0x4343,0x6D8F,0x3C47,0x6582,
    0xBB3F,0x46AB,0xAFE6,0x1AE2,0x03CF,0xFBFE,0x9AEC,0x7A88,0x1007,0xE0E3,
    0xA8AD,0x4236,0x3FFF,0x79A6,0x599C,0x623F,0xE175,0x46AB,0xFF01,0xB6AA,
    0x46C6,0xF872,0x4CCB,0x38D5,0x8B00,0x3AAA,0xFFC2,0xCAEB,0xAD8D,0x4FE6,
    0x779D,0xA73E,0x0038,0x001A,0xB056,0xFD2A,0xA846,0xC4C8,0xEC93,0xCE72,
    0x9A02,0xD8E2,0x5D8B,0x6FA9,0xAD8D,0xA9CC,0x6F19,0x83C4,0xDEDD,0x6DA9,
    0x52AB,0x5B1F,0xBFFF,0x7309,0xD936,0x9C57,0xFFCE,0x428C,0x7E7D,0xAEB4,
    0x6700,0x0055,0x2F1B,0xF56C,0x3BFA,0x5111,0xDF43,0x6585,0xDFD5,0x9584,
    0x54CA,0xAE65,0x288A,0x7340,0x00EE,0xED68,0x480A,0xAEEB,0xAD11,0x1F74,
    0x6C78,0xC96A,0xA962,0xF12E,0xFEEF,0xD8B0,0xDF63,0x815E,0x3306,0xAEAE,
    0x9D58,0xE553,0xBE97,0xBF8C,0xD221,0xADEA,0xF58E,0x6767,0x726C,0x775D,
    0xF7EF,0xAF5D,0xB41C,0x4C41,0x551E,0x3388,0x673F,0xF7AC,0x7A16,0x7694,
    0x29D6,0x1B3D,0x7BFA,0xE3CF,0x22CC,0x7FE0,0x327F,0x9CE6,0x119A,0xEF70,
    0xF220,0xEAAC,0x767F,0xDF05,0x8008,0x2E98,0x5880,0x99CF,0x3E03,0xC3E8,
    0x7CE0,0x3012,0x0209,0xD5B9,0xDF79,0x3612,0x3D7D,0xE55F,0x7EBB,0xBC10,
    0xBCB3,0x90BD,0x2BD7,0xCDF9,0xAABC,0x23D7,0xC0B7,0x86FF,0xAFF9,0x757E,
    0xF16C,0x2786,0x7CAA,0x97D7,0x4B73,0x5F25,0x4FD3,0x7525,0xFC7C,0x64BC,
    0x712F,0x5C5D,0x5D9F,0xAA9F,0x5EAD,0x01CB,0x25E0,0xFB0A,0xFE6C,0x8EEA,
    0xABFB,0xE430,0x3B98,0x930B,0x1EF8,0xF81D,0x5552,0xA70E,0x0B0F,0xD555,
    0x7858,0x3065,0x3A98,0x2AEF,0xE0C7,0xA478,0xF98B,0xFFF8
END_PACKED_BITMAP

PACKED_BITMAP($CASTLE,160,80,$CENTER,0,81)
    0x4006,0x5450,0xFB03,0x0100,0x3D02,0x0880,0x0000,0x000D,0xFF88,0x0008,
    0x55EA,0xEF03,0x818F,0xAAE3,0xF75F,0xC740,0xFD5F,0x5FAE,0x2BFF,0xEE0E,
    0xD75F,0xD55D,0x57EB,0x71D5,0x54EA,0xBCCF,0xD8FC,0x741D,0x9E1E,0xAAAA,
    0xF241,0xE85B,0x6B8E,0xEBBB,0xFA80,0xBFAB,0xA5D2,0xDB0F,0xE4FD,0x51EB,
    0xF8C5,0x7557,0x5E41,0x1FAF,0xAAAF,0x95AE,0xFE8F,0xF1D5,0x5633,0xEC73,
    0x9D12,0x506C,0x5D95,0xEB56,0x9F0B,0xAE38,0x0B11,0xB3AE,0x22F1,0xB2AE,
    0x466B,0xFEBD,0xCF50,0x5F8C,0xFA1C,0xD7E4,0xD07D,0x758E,0x03C7,0x3FE7,
    0x55FC,0xA8A2,0x1E9F,0xDD43,0xDCAA,0xF57B,0xFBA1,0xF81F,0xDD44,0x6E8A,
    0xE739,0x8C63,0x39CE,0x4B98,0xC631,0x9CE7,0x318A,0xA319,0xCF5D,0xFE98,
    0x7F9C,0xD71D,0x8F72,0x9CCE,0x8EFE,0xF8FD,0x6B1B,0xCEFF,0xDF7F,0xFEC7,
    0x3194,0xE73C,0x6E31,0xC68B,0x98C6,0x3468,0xF6C9,0xCF75,0x1B7F,0xB19A,
    0xEC8D,0x49F7,0x2ECE,0x2B2F,0xBDF6,0x3B0D,0xD3B0,0xFD76,0x81A7,0xAA9C,
    0xFFE0,0xACDA,0xB0B9,0xCFEB,0x98E8,0x5E24,0x4FFF,0xE45C,0x6E7F,0xFEAA,
    0xC62D,0xC6D7,0xC286,0x04A4,0x45FB,0x5613,0xBD8F,0x0760,0x80F5,0x9FDE,
    0xBB87,0x6703,0xC1D8,0xA602,0x6488,0x6121,0x19E7,0x3E17,0xBC04,0xC417,
    0x23B6,0xFB81,0xC0FB,0xB6C8,0x3002,0x9673,0xF76F,0xDC3B,0x0430,0x1D3B,
    0x0600,0x6673,0xD860,0xFC60,0xE381,0x4F0E,0x9D86,0x003C,0xD66C,0x62FE,
    0x677C,0xCE74,0x472F,0x5322,0x27B9,0x2C12,0x6FF3,0x18F6,0x7300,0x057A,
    0x0001,0x26C2,0x9F58,0x3839,0xE7E3,0x5202,0x3E38,0x6280,0xA100,0xCE79,
    0xDEC3,0x1D9C,0x1B70,0x000A,0x4074,0xEC07,0x4EC3,0xDFA6,0x180A,0x0FE2,
    0x0214,0x90E4,0xC210,0x1FDD,0x757F,0xF0A7,0xF438,0x2E3E,0x0078,0x360F,
    0xF9AC,0x87FF,0x9824,0x3B00,0x72EC,0x0FFF,0xE100,0xFFF6,0xB33F,0xFC62,
    0xC3A5,0xD3B0,0x354A,0xAA59,0x480F,0x9CF3,0xF6CC,0x0E96,0x99D7,0x2477,
    0x77CC,0x4B1D,0x8960,0xB318,0xA58D,0xC520,0xB086,0x1AA5,0x7636,0x3FAC,
    0xE1F8,0xD8EC,0x2B6B,0xB170,0xB6AE,0x40D8,0xEC5B,0xA3A6,0xC2A0,0x0B80,
    0x1783,0x75F6,0x41FF,0xF7A3,0xB3BE,0xAB09,0xCC24,0x1404,0x2C07,0xF7FC,
    0x86B7,0xF4E7,0xFDE1,0xD5D9,0x6CE8,0xFBB2,0x0AC6,0xB39F,0x836D,0x6157,
    0x6054,0x9BAE,0x41E7,0x7B93,0x13C5,0xAEC8,0x0746,0x062C,0x2754,0xBD67,
    0x1FF6,0xB33A,0xB3E1,0xE060,0x8F4D,0x8BB6,0x983E,0x7E03,0x9E03,0x86AC,
    0x07D8,0xD8F9,0xE007,0x8072,0xB0AA,0xB94E,0xC488,0xBFF9,0x62C0,0x9FE1,
    0xE0D8,0x782C,0x0E5A,0x605C,0xC077,0xF7C8,0x7B16,0x1DEC,0x3A73,0x18B1,
    0xB8A5,0xE6B6,0x37D8,0xD853,0xF59E,0x3F9B,0x1619,0xCC78,0x7FB0,0xE015,
    0xD4E1,0x61CE,0xE1D8,0x9E0B,0x70F0,0x6363,0xF5C0,0xE108,0xD677,0x5CAD,
    0x232A,0x585C,0x8EFE,0x7060,0xFFFD,0x6AC3,0x0000,0x12CD,0x8D80,0xF57A,
    0xF561,0xDBF1,0xE1D8,0x1008,0xFD9D,0x817A,0xEBE0,0x42BA,0xCFB6,0xA32C,
    0x318C,0x3012,0xFBE0,0x38DD,0x6763,0xC040,0xD0C4,0xF70C,0x1820,0x1AD7,
    0x911D,0x6C6B,0xD8C6,0x4000,0x4842,0x3BE0,0x38C9,0xDEBB,0x2700,0x0812,
    0x59FC,0x043A,0xB0D3,0xDB87,0x64E8,0x01D0,0x0327,0xC07A,0x5C83,0xDFFF,
    0x2447,0x7B56,0x1DF1,0x1D95,0x13EB,0x48B4,0xF58D,0xE9F9,0x749C,0x571C,
    0x0104,0x553F,0x8BA0,0x0AC0,0x139D,0x9C61,0xE9F9,0x9510,0xA0AD,0x49EE,
    0x1D80,0xFF01,0xC961,0xBEE1,0xD9B0,0x4A08,0x0EBC,0x3101,0xFF9C,0x223F,
    0x8E67,0x3F94,0xF810,0xE71B,0xA781,0x81D7,0x7DEC,0x6C7E,0xA580,0x9C1B,
    0x66A3,0x1FE9,0x8896,0x1FBD,0x4E1D,0x9FCA,0x6007,0x5EA9,0xE276,0x75B8,
    0x584F,0xF3FE,0x2F74,0x0F3A,0xCD4B,0xBDCC,0x765D,0xEE77,0xDDEC,0x2F72,
    0xF998,0x9053,0xFA76,0x78B3,0x0097,0xCE9B,0x0028,0xC5BB,0x56B8,0x6E6D,
    0x156F,0x6538,0x007F,0x1BB0,0xC0FF,0x3AF8,0xCE73,0xF0AB,0xB87E,0x75BB,
    0x3F13,0xBF5E,0x7E12,0xECF4,0x937A,0xF9BF,0x3557,0x847A,0xF816,0xEB7F,
    0xD7FC,0xBABF,0x78BB,0x13C3,0x3E55,0x4BEB,0xA5B9,0x2F92,0xA7EB,0xAAA9,
    0x8E43,0xE307,0x0630,0xF5C5,0x5559,0xFA89,0xCA87,0xFE10,0xE381,0xC1D8,
    0x15FC,0xD91D,0xC557,0xF7CC,0x18C2,0x1185,0x8F78,0x83E0,0x7555,0x4E89,
    0xCFD5,0x5578,0x5810,0x653A,0x982A,0xAFE0,0x47A4,0x78F9,0x8BFF,0xF800
END_PACKED_BITMAP

$$EXTERN

// +------------------+
// | External Section |
// +------------------+

// No external modules...

$$END
